# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class TestConfig(Base):
	"""The TestConfig class encapsulates a required testConfig node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the TestConfig property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'testConfig'

	def __init__(self, parent):
		super(TestConfig, self).__init__(parent)

	@property
	def ApplyMode(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('applyMode')
	@ApplyMode.setter
	def ApplyMode(self, value):
		self._set_attribute('applyMode', value)

	@property
	def AssignGroupType(self):
		"""The type assigned to the type.

		Returns:
			str(accumulated|distributed)
		"""
		return self._get_attribute('assignGroupType')
	@AssignGroupType.setter
	def AssignGroupType(self, value):
		self._set_attribute('assignGroupType', value)

	@property
	def BidirectionalOptionEnabled(self):
		"""If enabled, it shows the outer VLAN connections.

		Returns:
			bool
		"""
		return self._get_attribute('bidirectionalOptionEnabled')
	@BidirectionalOptionEnabled.setter
	def BidirectionalOptionEnabled(self, value):
		self._set_attribute('bidirectionalOptionEnabled', value)

	@property
	def BurstSize(self):
		"""The number of packets to send in a burst .

		Returns:
			number
		"""
		return self._get_attribute('burstSize')
	@BurstSize.setter
	def BurstSize(self, value):
		self._set_attribute('burstSize', value)

	@property
	def CalculateJitter(self):
		"""If true, calculates jitter.

		Returns:
			bool
		"""
		return self._get_attribute('calculateJitter')
	@CalculateJitter.setter
	def CalculateJitter(self, value):
		self._set_attribute('calculateJitter', value)

	@property
	def CalculateLatency(self):
		"""If true, calculates the latency.

		Returns:
			bool
		"""
		return self._get_attribute('calculateLatency')
	@CalculateLatency.setter
	def CalculateLatency(self, value):
		self._set_attribute('calculateLatency', value)

	@property
	def CalibrateLatency(self):
		"""If true, calibrates the latency.

		Returns:
			bool
		"""
		return self._get_attribute('calibrateLatency')
	@CalibrateLatency.setter
	def CalibrateLatency(self, value):
		self._set_attribute('calibrateLatency', value)

	@property
	def CountRandomFrameSize(self):
		"""If true, randomly counts the frame size.

		Returns:
			number
		"""
		return self._get_attribute('countRandomFrameSize')
	@CountRandomFrameSize.setter
	def CountRandomFrameSize(self, value):
		self._set_attribute('countRandomFrameSize', value)

	@property
	def DelayAfterTransmit(self):
		"""A delay that is inserted after transmit is complete, before it continues with the test.

		Returns:
			number
		"""
		return self._get_attribute('delayAfterTransmit')
	@DelayAfterTransmit.setter
	def DelayAfterTransmit(self, value):
		self._set_attribute('delayAfterTransmit', value)

	@property
	def DelayBetweenIterations(self):
		"""The delay in time between iterations of trasmit.

		Returns:
			number
		"""
		return self._get_attribute('delayBetweenIterations')
	@DelayBetweenIterations.setter
	def DelayBetweenIterations(self, value):
		self._set_attribute('delayBetweenIterations', value)

	@property
	def DelayMode(self):
		"""The mode of delay.

		Returns:
			str(average|max)
		"""
		return self._get_attribute('delayMode')
	@DelayMode.setter
	def DelayMode(self, value):
		self._set_attribute('delayMode', value)

	@property
	def DummyTrafficId(self):
		"""The id of the monitor traffic item

		Returns:
			str
		"""
		return self._get_attribute('dummyTrafficId')
	@DummyTrafficId.setter
	def DummyTrafficId(self, value):
		self._set_attribute('dummyTrafficId', value)

	@property
	def Duration(self):
		"""sec

		Returns:
			number
		"""
		return self._get_attribute('duration')
	@Duration.setter
	def Duration(self, value):
		self._set_attribute('duration', value)

	@property
	def EnableDataIntegrity(self):
		"""If true, enables data integrity test.

		Returns:
			bool
		"""
		return self._get_attribute('enableDataIntegrity')
	@EnableDataIntegrity.setter
	def EnableDataIntegrity(self, value):
		self._set_attribute('enableDataIntegrity', value)

	@property
	def EnableExtraIterations(self):
		"""If true, enables extra iterations.Sets extra iteration offset values.

		Returns:
			bool
		"""
		return self._get_attribute('enableExtraIterations')
	@EnableExtraIterations.setter
	def EnableExtraIterations(self, value):
		self._set_attribute('enableExtraIterations', value)

	@property
	def EnableExtraJoinFrames(self):
		"""If true, enables extra join frames.

		Returns:
			bool
		"""
		return self._get_attribute('enableExtraJoinFrames')
	@EnableExtraJoinFrames.setter
	def EnableExtraJoinFrames(self, value):
		self._set_attribute('enableExtraJoinFrames', value)

	@property
	def EnableFastConvergence(self):
		"""If true, enables fast convergence.

		Returns:
			bool
		"""
		return self._get_attribute('enableFastConvergence')
	@EnableFastConvergence.setter
	def EnableFastConvergence(self, value):
		self._set_attribute('enableFastConvergence', value)

	@property
	def EnableLayer2(self):
		"""If true, enables Layer2 protocols.

		Returns:
			bool
		"""
		return self._get_attribute('enableLayer2')
	@EnableLayer2.setter
	def EnableLayer2(self, value):
		self._set_attribute('enableLayer2', value)

	@property
	def EnableLeaveGroup(self):
		"""If true, enables leave group.

		Returns:
			bool
		"""
		return self._get_attribute('enableLeaveGroup')
	@EnableLeaveGroup.setter
	def EnableLeaveGroup(self, value):
		self._set_attribute('enableLeaveGroup', value)

	@property
	def EnableMinFrameSize(self):
		"""If true, enables minimum frame size.

		Returns:
			bool
		"""
		return self._get_attribute('enableMinFrameSize')
	@EnableMinFrameSize.setter
	def EnableMinFrameSize(self, value):
		self._set_attribute('enableMinFrameSize', value)

	@property
	def EnableMulticastQuerier(self):
		"""Enable Multicast Querier Settings

		Returns:
			bool
		"""
		return self._get_attribute('enableMulticastQuerier')
	@EnableMulticastQuerier.setter
	def EnableMulticastQuerier(self, value):
		self._set_attribute('enableMulticastQuerier', value)

	@property
	def EnableRouterAlert(self):
		"""If true, enables router alert.

		Returns:
			bool
		"""
		return self._get_attribute('enableRouterAlert')
	@EnableRouterAlert.setter
	def EnableRouterAlert(self, value):
		self._set_attribute('enableRouterAlert', value)

	@property
	def ExtraFramesFirstGroupAddress(self):
		"""The extra frames first group IP address.

		Returns:
			str
		"""
		return self._get_attribute('extraFramesFirstGroupAddress')
	@ExtraFramesFirstGroupAddress.setter
	def ExtraFramesFirstGroupAddress(self, value):
		self._set_attribute('extraFramesFirstGroupAddress', value)

	@property
	def ExtraFramesFirstGroupAddressIPv6(self):
		"""The extra frames first group IPv6 address.

		Returns:
			str
		"""
		return self._get_attribute('extraFramesFirstGroupAddressIPv6')
	@ExtraFramesFirstGroupAddressIPv6.setter
	def ExtraFramesFirstGroupAddressIPv6(self, value):
		self._set_attribute('extraFramesFirstGroupAddressIPv6', value)

	@property
	def ExtraFramesTotalGroupAddresses(self):
		"""The extra frames total group address.

		Returns:
			number
		"""
		return self._get_attribute('extraFramesTotalGroupAddresses')
	@ExtraFramesTotalGroupAddresses.setter
	def ExtraFramesTotalGroupAddresses(self, value):
		self._set_attribute('extraFramesTotalGroupAddresses', value)

	@property
	def ExtraIterationOffsets(self):
		"""Sets extra iteration offset values.

		Returns:
			str
		"""
		return self._get_attribute('extraIterationOffsets')
	@ExtraIterationOffsets.setter
	def ExtraIterationOffsets(self, value):
		self._set_attribute('extraIterationOffsets', value)

	@property
	def FastConvergenceDuration(self):
		"""sec

		Returns:
			number
		"""
		return self._get_attribute('fastConvergenceDuration')
	@FastConvergenceDuration.setter
	def FastConvergenceDuration(self, value):
		self._set_attribute('fastConvergenceDuration', value)

	@property
	def FastConvergenceThreshold(self):
		"""If true, enables fast convergence threshold value.

		Returns:
			number
		"""
		return self._get_attribute('fastConvergenceThreshold')
	@FastConvergenceThreshold.setter
	def FastConvergenceThreshold(self, value):
		self._set_attribute('fastConvergenceThreshold', value)

	@property
	def FirstMulticastDestMACAddress(self):
		"""The first multicast destination MAC address.

		Returns:
			str
		"""
		return self._get_attribute('firstMulticastDestMACAddress')
	@FirstMulticastDestMACAddress.setter
	def FirstMulticastDestMACAddress(self, value):
		self._set_attribute('firstMulticastDestMACAddress', value)

	@property
	def FloodedFramesEnabled(self):
		"""If true, it enables the flooded frames statistics

		Returns:
			bool
		"""
		return self._get_attribute('floodedFramesEnabled')
	@FloodedFramesEnabled.setter
	def FloodedFramesEnabled(self, value):
		self._set_attribute('floodedFramesEnabled', value)

	@property
	def ForceRegenerate(self):
		"""Initiates a forced regeneration.

		Returns:
			bool
		"""
		return self._get_attribute('forceRegenerate')
	@ForceRegenerate.setter
	def ForceRegenerate(self, value):
		self._set_attribute('forceRegenerate', value)

	@property
	def FrameSizeMode(self):
		"""This attribute is the frame size mode for the Quad Gaussian.

		Returns:
			str(custom|increment|random)
		"""
		return self._get_attribute('frameSizeMode')
	@FrameSizeMode.setter
	def FrameSizeMode(self, value):
		self._set_attribute('frameSizeMode', value)

	@property
	def Framesize(self):
		"""Bytes

		Returns:
			number
		"""
		return self._get_attribute('framesize')
	@Framesize.setter
	def Framesize(self, value):
		self._set_attribute('framesize', value)

	@property
	def FramesizeList(self):
		"""The list of the available frame size.

		Returns:
			list(str)
		"""
		return self._get_attribute('framesizeList')
	@FramesizeList.setter
	def FramesizeList(self, value):
		self._set_attribute('framesizeList', value)

	@property
	def GroupCapacityGreaterThan(self):
		"""The greater value of group capacity.

		Returns:
			number
		"""
		return self._get_attribute('groupCapacityGreaterThan')
	@GroupCapacityGreaterThan.setter
	def GroupCapacityGreaterThan(self, value):
		self._set_attribute('groupCapacityGreaterThan', value)

	@property
	def GroupDistributionType(self):
		"""The type of group distribution.

		Returns:
			str(acrossHosts|acrossPorts)
		"""
		return self._get_attribute('groupDistributionType')
	@GroupDistributionType.setter
	def GroupDistributionType(self, value):
		self._set_attribute('groupDistributionType', value)

	@property
	def IgmpV1Timeout(self):
		"""The IGMPv1 timeout value.

		Returns:
			number
		"""
		return self._get_attribute('igmpV1Timeout')
	@IgmpV1Timeout.setter
	def IgmpV1Timeout(self, value):
		self._set_attribute('igmpV1Timeout', value)

	@property
	def IgmpVersion(self):
		"""The version of IGMP.

		Returns:
			number
		"""
		return self._get_attribute('igmpVersion')
	@IgmpVersion.setter
	def IgmpVersion(self, value):
		self._set_attribute('igmpVersion', value)

	@property
	def Igmpv3MessageType(self):
		"""The message type of IGMPv3.

		Returns:
			str(exclude|include)
		"""
		return self._get_attribute('igmpv3MessageType')
	@Igmpv3MessageType.setter
	def Igmpv3MessageType(self, value):
		self._set_attribute('igmpv3MessageType', value)

	@property
	def Igmpv3SourceAddrList(self):
		"""The source address list of IGMPv3.

		Returns:
			str
		"""
		return self._get_attribute('igmpv3SourceAddrList')
	@Igmpv3SourceAddrList.setter
	def Igmpv3SourceAddrList(self, value):
		self._set_attribute('igmpv3SourceAddrList', value)

	@property
	def IncMulticastDestMACAddress(self):
		"""The incrementing multicast destination MAC address.

		Returns:
			str
		"""
		return self._get_attribute('incMulticastDestMACAddress')
	@IncMulticastDestMACAddress.setter
	def IncMulticastDestMACAddress(self, value):
		self._set_attribute('incMulticastDestMACAddress', value)

	@property
	def IncPortMACAddress(self):
		"""The incrementing MAC address of the port.

		Returns:
			str
		"""
		return self._get_attribute('incPortMACAddress')
	@IncPortMACAddress.setter
	def IncPortMACAddress(self, value):
		self._set_attribute('incPortMACAddress', value)

	@property
	def IncrAddresses(self):
		"""The incremental address.

		Returns:
			number
		"""
		return self._get_attribute('incrAddresses')
	@IncrAddresses.setter
	def IncrAddresses(self, value):
		self._set_attribute('incrAddresses', value)

	@property
	def IncrStep(self):
		"""The incremental step value.

		Returns:
			number
		"""
		return self._get_attribute('incrStep')
	@IncrStep.setter
	def IncrStep(self, value):
		self._set_attribute('incrStep', value)

	@property
	def InitialRate(self):
		"""The first rate of transmission.

		Returns:
			str
		"""
		return self._get_attribute('initialRate')
	@InitialRate.setter
	def InitialRate(self, value):
		self._set_attribute('initialRate', value)

	@property
	def Ipv4Address(self):
		"""The allocated IPv4 address for this interface.

		Returns:
			str
		"""
		return self._get_attribute('ipv4Address')
	@Ipv4Address.setter
	def Ipv4Address(self, value):
		self._set_attribute('ipv4Address', value)

	@property
	def Ipv6Address(self):
		"""The allocated IPv6address for this interface.

		Returns:
			str
		"""
		return self._get_attribute('ipv6Address')
	@Ipv6Address.setter
	def Ipv6Address(self, value):
		self._set_attribute('ipv6Address', value)

	@property
	def IsIPv6(self):
		"""Signifies if the address is an ipv6 address.

		Returns:
			str
		"""
		return self._get_attribute('isIPv6')
	@IsIPv6.setter
	def IsIPv6(self, value):
		self._set_attribute('isIPv6', value)

	@property
	def IsMulticastAutomaticFrameData(self):
		"""Signifies automatic frameData for multicast.

		Returns:
			str
		"""
		return self._get_attribute('isMulticastAutomaticFrameData')
	@IsMulticastAutomaticFrameData.setter
	def IsMulticastAutomaticFrameData(self, value):
		self._set_attribute('isMulticastAutomaticFrameData', value)

	@property
	def JoinDelayRefUnit(self):
		"""The reference unit of join delay.

		Returns:
			str(ms|ns|us)
		"""
		return self._get_attribute('joinDelayRefUnit')
	@JoinDelayRefUnit.setter
	def JoinDelayRefUnit(self, value):
		self._set_attribute('joinDelayRefUnit', value)

	@property
	def JoinDelayRefValue(self):
		"""The reference value of join delay.

		Returns:
			number
		"""
		return self._get_attribute('joinDelayRefValue')
	@JoinDelayRefValue.setter
	def JoinDelayRefValue(self, value):
		self._set_attribute('joinDelayRefValue', value)

	@property
	def JoinLeaveAlgorithm(self):
		"""The algorithm for join leave.

		Returns:
			str(joinExisting|joinNew)
		"""
		return self._get_attribute('joinLeaveAlgorithm')
	@JoinLeaveAlgorithm.setter
	def JoinLeaveAlgorithm(self, value):
		self._set_attribute('joinLeaveAlgorithm', value)

	@property
	def JoinLeaveFramesPerGroup(self):
		"""The join leave frames per group.

		Returns:
			number
		"""
		return self._get_attribute('joinLeaveFramesPerGroup')
	@JoinLeaveFramesPerGroup.setter
	def JoinLeaveFramesPerGroup(self, value):
		self._set_attribute('joinLeaveFramesPerGroup', value)

	@property
	def JoinLeaveMode(self):
		"""The mode of join leave delay.

		Returns:
			str(join|joinLeave|leave)
		"""
		return self._get_attribute('joinLeaveMode')
	@JoinLeaveMode.setter
	def JoinLeaveMode(self, value):
		self._set_attribute('joinLeaveMode', value)

	@property
	def JoinLeaveMultiplier(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('joinLeaveMultiplier')
	@JoinLeaveMultiplier.setter
	def JoinLeaveMultiplier(self, value):
		self._set_attribute('joinLeaveMultiplier', value)

	@property
	def JoinLeaveRate(self):
		"""The join leave rate.

		Returns:
			number
		"""
		return self._get_attribute('joinLeaveRate')
	@JoinLeaveRate.setter
	def JoinLeaveRate(self, value):
		self._set_attribute('joinLeaveRate', value)

	@property
	def JoinLeaveWaitTime(self):
		"""The wait time for join delay.

		Returns:
			number
		"""
		return self._get_attribute('joinLeaveWaitTime')
	@JoinLeaveWaitTime.setter
	def JoinLeaveWaitTime(self, value):
		self._set_attribute('joinLeaveWaitTime', value)

	@property
	def LatencyType(self):
		"""The type of latency

		Returns:
			str(cutThrough|storeForward)
		"""
		return self._get_attribute('latencyType')
	@LatencyType.setter
	def LatencyType(self, value):
		self._set_attribute('latencyType', value)

	@property
	def LeaveDelayRefUnit(self):
		"""The reference unit of leave delay.

		Returns:
			str(ms|ns|us)
		"""
		return self._get_attribute('leaveDelayRefUnit')
	@LeaveDelayRefUnit.setter
	def LeaveDelayRefUnit(self, value):
		self._set_attribute('leaveDelayRefUnit', value)

	@property
	def LeaveDelayRefValue(self):
		"""The leave delay reference value.

		Returns:
			number
		"""
		return self._get_attribute('leaveDelayRefValue')
	@LeaveDelayRefValue.setter
	def LeaveDelayRefValue(self, value):
		self._set_attribute('leaveDelayRefValue', value)

	@property
	def LoadInitialRate(self):
		"""The initial load rate.

		Returns:
			number
		"""
		return self._get_attribute('loadInitialRate')
	@LoadInitialRate.setter
	def LoadInitialRate(self, value):
		self._set_attribute('loadInitialRate', value)

	@property
	def LoadType(self):
		"""The type of the payload setting

		Returns:
			str(binary|combo|custom|fixed|increment|quickSearch|random|step|unchanged)
		"""
		return self._get_attribute('loadType')
	@LoadType.setter
	def LoadType(self, value):
		self._set_attribute('loadType', value)

	@property
	def LoadUnit(self):
		"""Specifies the step rate of the load unit.

		Returns:
			str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)
		"""
		return self._get_attribute('loadUnit')
	@LoadUnit.setter
	def LoadUnit(self, value):
		self._set_attribute('loadUnit', value)

	@property
	def MapType(self):
		"""The POS traffic map type.

		Returns:
			str
		"""
		return self._get_attribute('mapType')
	@MapType.setter
	def MapType(self, value):
		self._set_attribute('mapType', value)

	@property
	def MaxIncrementFrameSize(self):
		"""The maximum incremental value of the frame size.

		Returns:
			number
		"""
		return self._get_attribute('maxIncrementFrameSize')
	@MaxIncrementFrameSize.setter
	def MaxIncrementFrameSize(self, value):
		self._set_attribute('maxIncrementFrameSize', value)

	@property
	def MaxRandomFrameSize(self):
		"""The maximum random frame size to be sent.

		Returns:
			number
		"""
		return self._get_attribute('maxRandomFrameSize')
	@MaxRandomFrameSize.setter
	def MaxRandomFrameSize(self, value):
		self._set_attribute('maxRandomFrameSize', value)

	@property
	def MaxRate(self):
		"""The maximum rate.

		Returns:
			number
		"""
		return self._get_attribute('maxRate')
	@MaxRate.setter
	def MaxRate(self, value):
		self._set_attribute('maxRate', value)

	@property
	def MinIncrementFrameSize(self):
		"""The minimum incremental value of the frame size.

		Returns:
			number
		"""
		return self._get_attribute('minIncrementFrameSize')
	@MinIncrementFrameSize.setter
	def MinIncrementFrameSize(self, value):
		self._set_attribute('minIncrementFrameSize', value)

	@property
	def MinRandomFrameSize(self):
		"""The minimum random frame size to be sent.

		Returns:
			number
		"""
		return self._get_attribute('minRandomFrameSize')
	@MinRandomFrameSize.setter
	def MinRandomFrameSize(self, value):
		self._set_attribute('minRandomFrameSize', value)

	@property
	def MixedClassMulticast(self):
		"""The mixed multicast class.

		Returns:
			str
		"""
		return self._get_attribute('mixedClassMulticast')
	@MixedClassMulticast.setter
	def MixedClassMulticast(self, value):
		self._set_attribute('mixedClassMulticast', value)

	@property
	def MldVersion(self):
		"""The version of MLD.

		Returns:
			number
		"""
		return self._get_attribute('mldVersion')
	@MldVersion.setter
	def MldVersion(self, value):
		self._set_attribute('mldVersion', value)

	@property
	def Mldv2MessageType(self):
		"""Signifies the message type of mldv2.

		Returns:
			str(exclude|include)
		"""
		return self._get_attribute('mldv2MessageType')
	@Mldv2MessageType.setter
	def Mldv2MessageType(self, value):
		self._set_attribute('mldv2MessageType', value)

	@property
	def Mldv2SourceAddrList(self):
		"""The source address list of mldv2.

		Returns:
			str
		"""
		return self._get_attribute('mldv2SourceAddrList')
	@Mldv2SourceAddrList.setter
	def Mldv2SourceAddrList(self, value):
		self._set_attribute('mldv2SourceAddrList', value)

	@property
	def NumAddresses(self):
		"""The number address.

		Returns:
			number
		"""
		return self._get_attribute('numAddresses')
	@NumAddresses.setter
	def NumAddresses(self, value):
		self._set_attribute('numAddresses', value)

	@property
	def NumIterations(self):
		"""The number of iterations.

		Returns:
			number
		"""
		return self._get_attribute('numIterations')
	@NumIterations.setter
	def NumIterations(self, value):
		self._set_attribute('numIterations', value)

	@property
	def NumTrials(self):
		"""%

		Returns:
			number
		"""
		return self._get_attribute('numTrials')
	@NumTrials.setter
	def NumTrials(self, value):
		self._set_attribute('numTrials', value)

	@property
	def NumberOfExtraJoins(self):
		"""The number of extra joins in the address.

		Returns:
			number
		"""
		return self._get_attribute('numberOfExtraJoins')
	@NumberOfExtraJoins.setter
	def NumberOfExtraJoins(self, value):
		self._set_attribute('numberOfExtraJoins', value)

	@property
	def Numtrials(self):
		"""The number address.

		Returns:
			number
		"""
		return self._get_attribute('numtrials')
	@Numtrials.setter
	def Numtrials(self, value):
		self._set_attribute('numtrials', value)

	@property
	def OffsetTime(self):
		"""The offset time value.

		Returns:
			number
		"""
		return self._get_attribute('offsetTime')
	@OffsetTime.setter
	def OffsetTime(self, value):
		self._set_attribute('offsetTime', value)

	@property
	def PercentMaxRate(self):
		"""Specifies the step rate of the load unit.

		Returns:
			number
		"""
		return self._get_attribute('percentMaxRate')
	@PercentMaxRate.setter
	def PercentMaxRate(self, value):
		self._set_attribute('percentMaxRate', value)

	@property
	def PercentMulticastFrames(self):
		"""The percentage of multicast frames.

		Returns:
			number
		"""
		return self._get_attribute('percentMulticastFrames')
	@PercentMulticastFrames.setter
	def PercentMulticastFrames(self, value):
		self._set_attribute('percentMulticastFrames', value)

	@property
	def PercentUnicastFrames(self):
		"""The percentage of unicast frames.

		Returns:
			number
		"""
		return self._get_attribute('percentUnicastFrames')
	@PercentUnicastFrames.setter
	def PercentUnicastFrames(self, value):
		self._set_attribute('percentUnicastFrames', value)

	@property
	def PortMACAddress(self):
		"""The MAC address of the port.

		Returns:
			str
		"""
		return self._get_attribute('portMACAddress')
	@PortMACAddress.setter
	def PortMACAddress(self, value):
		self._set_attribute('portMACAddress', value)

	@property
	def ProtocolItem(self):
		"""Protocol Items

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])
		"""
		return self._get_attribute('protocolItem')
	@ProtocolItem.setter
	def ProtocolItem(self, value):
		self._set_attribute('protocolItem', value)

	@property
	def RatePass(self):
		"""A Pass criteria applied to each trial in the test to determine whether the trialpassed or failed.

		Returns:
			number
		"""
		return self._get_attribute('ratePass')
	@RatePass.setter
	def RatePass(self, value):
		self._set_attribute('ratePass', value)

	@property
	def ReportSequenceError(self):
		"""Reports sequence errors in the test result.

		Returns:
			bool
		"""
		return self._get_attribute('reportSequenceError')
	@ReportSequenceError.setter
	def ReportSequenceError(self, value):
		self._set_attribute('reportSequenceError', value)

	@property
	def SendJoinsBeforeLeave(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('sendJoinsBeforeLeave')
	@SendJoinsBeforeLeave.setter
	def SendJoinsBeforeLeave(self, value):
		self._set_attribute('sendJoinsBeforeLeave', value)

	@property
	def StaggeredStart(self):
		"""Starts test with a stagger.

		Returns:
			bool
		"""
		return self._get_attribute('staggeredStart')
	@StaggeredStart.setter
	def StaggeredStart(self, value):
		self._set_attribute('staggeredStart', value)

	@property
	def StepIncrementFrameSize(self):
		"""The incremental step value of the frame size.

		Returns:
			number
		"""
		return self._get_attribute('stepIncrementFrameSize')
	@StepIncrementFrameSize.setter
	def StepIncrementFrameSize(self, value):
		self._set_attribute('stepIncrementFrameSize', value)

	@property
	def SupportedTrafficTypes(self):
		"""The traffic types supported.

		Returns:
			str
		"""
		return self._get_attribute('supportedTrafficTypes')
	@SupportedTrafficTypes.setter
	def SupportedTrafficTypes(self, value):
		self._set_attribute('supportedTrafficTypes', value)

	@property
	def TestTrafficType(self):
		"""It signifies the test traffic type value.

		Returns:
			str
		"""
		return self._get_attribute('testTrafficType')
	@TestTrafficType.setter
	def TestTrafficType(self, value):
		self._set_attribute('testTrafficType', value)

	@property
	def TrafficBeforeJoinLeave(self):
		"""The traffic sent before join leave.

		Returns:
			bool
		"""
		return self._get_attribute('trafficBeforeJoinLeave')
	@TrafficBeforeJoinLeave.setter
	def TrafficBeforeJoinLeave(self, value):
		self._set_attribute('trafficBeforeJoinLeave', value)

	@property
	def TxDelay(self):
		"""Specifies the amount of delay after every transmit.

		Returns:
			number
		"""
		return self._get_attribute('txDelay')
	@TxDelay.setter
	def TxDelay(self, value):
		self._set_attribute('txDelay', value)

	@property
	def Use3376mode(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('use3376mode')
	@Use3376mode.setter
	def Use3376mode(self, value):
		self._set_attribute('use3376mode', value)

	@property
	def UsePercentOffsets(self):
		"""Uses percentage offset value.

		Returns:
			bool
		"""
		return self._get_attribute('usePercentOffsets')
	@UsePercentOffsets.setter
	def UsePercentOffsets(self, value):
		self._set_attribute('usePercentOffsets', value)

	def update(self, ApplyMode=None, AssignGroupType=None, BidirectionalOptionEnabled=None, BurstSize=None, CalculateJitter=None, CalculateLatency=None, CalibrateLatency=None, CountRandomFrameSize=None, DelayAfterTransmit=None, DelayBetweenIterations=None, DelayMode=None, DummyTrafficId=None, Duration=None, EnableDataIntegrity=None, EnableExtraIterations=None, EnableExtraJoinFrames=None, EnableFastConvergence=None, EnableLayer2=None, EnableLeaveGroup=None, EnableMinFrameSize=None, EnableMulticastQuerier=None, EnableRouterAlert=None, ExtraFramesFirstGroupAddress=None, ExtraFramesFirstGroupAddressIPv6=None, ExtraFramesTotalGroupAddresses=None, ExtraIterationOffsets=None, FastConvergenceDuration=None, FastConvergenceThreshold=None, FirstMulticastDestMACAddress=None, FloodedFramesEnabled=None, ForceRegenerate=None, FrameSizeMode=None, Framesize=None, FramesizeList=None, GroupCapacityGreaterThan=None, GroupDistributionType=None, IgmpV1Timeout=None, IgmpVersion=None, Igmpv3MessageType=None, Igmpv3SourceAddrList=None, IncMulticastDestMACAddress=None, IncPortMACAddress=None, IncrAddresses=None, IncrStep=None, InitialRate=None, Ipv4Address=None, Ipv6Address=None, IsIPv6=None, IsMulticastAutomaticFrameData=None, JoinDelayRefUnit=None, JoinDelayRefValue=None, JoinLeaveAlgorithm=None, JoinLeaveFramesPerGroup=None, JoinLeaveMode=None, JoinLeaveMultiplier=None, JoinLeaveRate=None, JoinLeaveWaitTime=None, LatencyType=None, LeaveDelayRefUnit=None, LeaveDelayRefValue=None, LoadInitialRate=None, LoadType=None, LoadUnit=None, MapType=None, MaxIncrementFrameSize=None, MaxRandomFrameSize=None, MaxRate=None, MinIncrementFrameSize=None, MinRandomFrameSize=None, MixedClassMulticast=None, MldVersion=None, Mldv2MessageType=None, Mldv2SourceAddrList=None, NumAddresses=None, NumIterations=None, NumTrials=None, NumberOfExtraJoins=None, Numtrials=None, OffsetTime=None, PercentMaxRate=None, PercentMulticastFrames=None, PercentUnicastFrames=None, PortMACAddress=None, ProtocolItem=None, RatePass=None, ReportSequenceError=None, SendJoinsBeforeLeave=None, StaggeredStart=None, StepIncrementFrameSize=None, SupportedTrafficTypes=None, TestTrafficType=None, TrafficBeforeJoinLeave=None, TxDelay=None, Use3376mode=None, UsePercentOffsets=None):
		"""Updates a child instance of testConfig on the server.

		Args:
			ApplyMode (str): NOT DEFINED
			AssignGroupType (str(accumulated|distributed)): The type assigned to the type.
			BidirectionalOptionEnabled (bool): If enabled, it shows the outer VLAN connections.
			BurstSize (number): The number of packets to send in a burst .
			CalculateJitter (bool): If true, calculates jitter.
			CalculateLatency (bool): If true, calculates the latency.
			CalibrateLatency (bool): If true, calibrates the latency.
			CountRandomFrameSize (number): If true, randomly counts the frame size.
			DelayAfterTransmit (number): A delay that is inserted after transmit is complete, before it continues with the test.
			DelayBetweenIterations (number): The delay in time between iterations of trasmit.
			DelayMode (str(average|max)): The mode of delay.
			DummyTrafficId (str): The id of the monitor traffic item
			Duration (number): sec
			EnableDataIntegrity (bool): If true, enables data integrity test.
			EnableExtraIterations (bool): If true, enables extra iterations.Sets extra iteration offset values.
			EnableExtraJoinFrames (bool): If true, enables extra join frames.
			EnableFastConvergence (bool): If true, enables fast convergence.
			EnableLayer2 (bool): If true, enables Layer2 protocols.
			EnableLeaveGroup (bool): If true, enables leave group.
			EnableMinFrameSize (bool): If true, enables minimum frame size.
			EnableMulticastQuerier (bool): Enable Multicast Querier Settings
			EnableRouterAlert (bool): If true, enables router alert.
			ExtraFramesFirstGroupAddress (str): The extra frames first group IP address.
			ExtraFramesFirstGroupAddressIPv6 (str): The extra frames first group IPv6 address.
			ExtraFramesTotalGroupAddresses (number): The extra frames total group address.
			ExtraIterationOffsets (str): Sets extra iteration offset values.
			FastConvergenceDuration (number): sec
			FastConvergenceThreshold (number): If true, enables fast convergence threshold value.
			FirstMulticastDestMACAddress (str): The first multicast destination MAC address.
			FloodedFramesEnabled (bool): If true, it enables the flooded frames statistics
			ForceRegenerate (bool): Initiates a forced regeneration.
			FrameSizeMode (str(custom|increment|random)): This attribute is the frame size mode for the Quad Gaussian.
			Framesize (number): Bytes
			FramesizeList (list(str)): The list of the available frame size.
			GroupCapacityGreaterThan (number): The greater value of group capacity.
			GroupDistributionType (str(acrossHosts|acrossPorts)): The type of group distribution.
			IgmpV1Timeout (number): The IGMPv1 timeout value.
			IgmpVersion (number): The version of IGMP.
			Igmpv3MessageType (str(exclude|include)): The message type of IGMPv3.
			Igmpv3SourceAddrList (str): The source address list of IGMPv3.
			IncMulticastDestMACAddress (str): The incrementing multicast destination MAC address.
			IncPortMACAddress (str): The incrementing MAC address of the port.
			IncrAddresses (number): The incremental address.
			IncrStep (number): The incremental step value.
			InitialRate (str): The first rate of transmission.
			Ipv4Address (str): The allocated IPv4 address for this interface.
			Ipv6Address (str): The allocated IPv6address for this interface.
			IsIPv6 (str): Signifies if the address is an ipv6 address.
			IsMulticastAutomaticFrameData (str): Signifies automatic frameData for multicast.
			JoinDelayRefUnit (str(ms|ns|us)): The reference unit of join delay.
			JoinDelayRefValue (number): The reference value of join delay.
			JoinLeaveAlgorithm (str(joinExisting|joinNew)): The algorithm for join leave.
			JoinLeaveFramesPerGroup (number): The join leave frames per group.
			JoinLeaveMode (str(join|joinLeave|leave)): The mode of join leave delay.
			JoinLeaveMultiplier (number): NOT DEFINED
			JoinLeaveRate (number): The join leave rate.
			JoinLeaveWaitTime (number): The wait time for join delay.
			LatencyType (str(cutThrough|storeForward)): The type of latency
			LeaveDelayRefUnit (str(ms|ns|us)): The reference unit of leave delay.
			LeaveDelayRefValue (number): The leave delay reference value.
			LoadInitialRate (number): The initial load rate.
			LoadType (str(binary|combo|custom|fixed|increment|quickSearch|random|step|unchanged)): The type of the payload setting
			LoadUnit (str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)): Specifies the step rate of the load unit.
			MapType (str): The POS traffic map type.
			MaxIncrementFrameSize (number): The maximum incremental value of the frame size.
			MaxRandomFrameSize (number): The maximum random frame size to be sent.
			MaxRate (number): The maximum rate.
			MinIncrementFrameSize (number): The minimum incremental value of the frame size.
			MinRandomFrameSize (number): The minimum random frame size to be sent.
			MixedClassMulticast (str): The mixed multicast class.
			MldVersion (number): The version of MLD.
			Mldv2MessageType (str(exclude|include)): Signifies the message type of mldv2.
			Mldv2SourceAddrList (str): The source address list of mldv2.
			NumAddresses (number): The number address.
			NumIterations (number): The number of iterations.
			NumTrials (number): %
			NumberOfExtraJoins (number): The number of extra joins in the address.
			Numtrials (number): The number address.
			OffsetTime (number): The offset time value.
			PercentMaxRate (number): Specifies the step rate of the load unit.
			PercentMulticastFrames (number): The percentage of multicast frames.
			PercentUnicastFrames (number): The percentage of unicast frames.
			PortMACAddress (str): The MAC address of the port.
			ProtocolItem (list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])): Protocol Items
			RatePass (number): A Pass criteria applied to each trial in the test to determine whether the trialpassed or failed.
			ReportSequenceError (bool): Reports sequence errors in the test result.
			SendJoinsBeforeLeave (bool): 
			StaggeredStart (bool): Starts test with a stagger.
			StepIncrementFrameSize (number): The incremental step value of the frame size.
			SupportedTrafficTypes (str): The traffic types supported.
			TestTrafficType (str): It signifies the test traffic type value.
			TrafficBeforeJoinLeave (bool): The traffic sent before join leave.
			TxDelay (number): Specifies the amount of delay after every transmit.
			Use3376mode (bool): 
			UsePercentOffsets (bool): Uses percentage offset value.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def Apply(self):
		"""Executes the apply operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('apply', payload=payload, response_object=None)

	def ApplyAsync(self):
		"""Executes the applyAsync operation on the server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsync', payload=payload, response_object=None)

	def ApplyAsyncResult(self):
		"""Executes the applyAsyncResult operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsyncResult', payload=payload, response_object=None)

	def ApplyITWizardConfiguration(self):
		"""Executes the applyITWizardConfiguration operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyITWizardConfiguration', payload=payload, response_object=None)

	def GenerateReport(self):
		"""Executes the generateReport operation on the server.

		Generate a PDF report for the last succesfull test run.

			Returns:
				str: This method is asynchronous and has no return value.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('generateReport', payload=payload, response_object=None)

	def Run(self, *args, **kwargs):
		"""Executes the run operation on the server.

		Starts the specified Quick Test and waits for its execution to finish.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		run()list

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		run(InputParameters:string)list
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('run', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Starts the specified Quick Test.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(InputParameters:string)
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self):
		"""Executes the stop operation on the server.

		Stops the currently running Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('stop', payload=payload, response_object=None)

	def WaitForTest(self):
		"""Executes the waitForTest operation on the server.

		Waits for the execution of the specified Quick Test to be completed.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('waitForTest', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class LearnedInformation(Base):
	"""The LearnedInformation class encapsulates a system managed learnedInformation node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the LearnedInformation property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'learnedInformation'

	def __init__(self, parent):
		super(LearnedInformation, self).__init__(parent)

	@property
	def GeneralLearnedInfo(self):
		"""An instance of the GeneralLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.mplsoam.learnedinformation.generallearnedinfo.generallearnedinfo.GeneralLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.mplsoam.learnedinformation.generallearnedinfo.generallearnedinfo import GeneralLearnedInfo
		return GeneralLearnedInfo(self)

	@property
	def TriggeredPingLearnedInfo(self):
		"""An instance of the TriggeredPingLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.mplsoam.learnedinformation.triggeredpinglearnedinfo.triggeredpinglearnedinfo.TriggeredPingLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.mplsoam.learnedinformation.triggeredpinglearnedinfo.triggeredpinglearnedinfo import TriggeredPingLearnedInfo
		return TriggeredPingLearnedInfo(self)

	@property
	def TriggeredTracerouteLearnedInfo(self):
		"""An instance of the TriggeredTracerouteLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.mplsoam.learnedinformation.triggeredtraceroutelearnedinfo.triggeredtraceroutelearnedinfo.TriggeredTracerouteLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.mplsoam.learnedinformation.triggeredtraceroutelearnedinfo.triggeredtraceroutelearnedinfo import TriggeredTracerouteLearnedInfo
		return TriggeredTracerouteLearnedInfo(self)

	@property
	def DestinationAddressIpv4(self):
		"""This signifies the destination IPv4 address.

		Returns:
			str
		"""
		return self._get_attribute('destinationAddressIpv4')
	@DestinationAddressIpv4.setter
	def DestinationAddressIpv4(self, value):
		self._set_attribute('destinationAddressIpv4', value)

	@property
	def DownstreamAddressType(self):
		"""This signifies the address type of the downstream traffic. Possible values include Ipv4Numbered and Ipv4UnNumbered.

		Returns:
			str(ipv4Numbered|ipv4UnNumbered)
		"""
		return self._get_attribute('downstreamAddressType')
	@DownstreamAddressType.setter
	def DownstreamAddressType(self, value):
		self._set_attribute('downstreamAddressType', value)

	@property
	def DownstreamInterfaceAddress(self):
		"""This signifies the interface address of the downstream LSR.

		Returns:
			str
		"""
		return self._get_attribute('downstreamInterfaceAddress')
	@DownstreamInterfaceAddress.setter
	def DownstreamInterfaceAddress(self, value):
		self._set_attribute('downstreamInterfaceAddress', value)

	@property
	def DownstreamIpAddress(self):
		"""This signifies the IPv4/IPv6 address of the downstream LSR.

		Returns:
			str
		"""
		return self._get_attribute('downstreamIpAddress')
	@DownstreamIpAddress.setter
	def DownstreamIpAddress(self, value):
		self._set_attribute('downstreamIpAddress', value)

	@property
	def EchoResponseTimeoutMs(self):
		"""This signifies the minimum tiomeout interval, in milliseconds, between received Echo packets that this interface is capable of supporting.

		Returns:
			number
		"""
		return self._get_attribute('echoResponseTimeoutMs')
	@EchoResponseTimeoutMs.setter
	def EchoResponseTimeoutMs(self, value):
		self._set_attribute('echoResponseTimeoutMs', value)

	@property
	def EnableAdvance(self):
		"""This signifies the enablement of advance.

		Returns:
			bool
		"""
		return self._get_attribute('enableAdvance')
	@EnableAdvance.setter
	def EnableAdvance(self, value):
		self._set_attribute('enableAdvance', value)

	@property
	def EnableDsiFlag(self):
		"""This signifies the activation of the DS I Flag.

		Returns:
			bool
		"""
		return self._get_attribute('enableDsiFlag')
	@EnableDsiFlag.setter
	def EnableDsiFlag(self, value):
		self._set_attribute('enableDsiFlag', value)

	@property
	def EnableDsnFlag(self):
		"""This signifies the activation of the DN S Flag.

		Returns:
			bool
		"""
		return self._get_attribute('enableDsnFlag')
	@EnableDsnFlag.setter
	def EnableDsnFlag(self, value):
		self._set_attribute('enableDsnFlag', value)

	@property
	def EnableFecValidation(self):
		"""This signifies the selection of the check box to enable FEC validation.

		Returns:
			bool
		"""
		return self._get_attribute('enableFecValidation')
	@EnableFecValidation.setter
	def EnableFecValidation(self, value):
		self._set_attribute('enableFecValidation', value)

	@property
	def EnableIncludeDownstreamMappingTlv(self):
		"""This signifies the inclusion of the downstream mapping TLV in triggered Trace Route.

		Returns:
			bool
		"""
		return self._get_attribute('enableIncludeDownstreamMappingTlv')
	@EnableIncludeDownstreamMappingTlv.setter
	def EnableIncludeDownstreamMappingTlv(self, value):
		self._set_attribute('enableIncludeDownstreamMappingTlv', value)

	@property
	def EnableIncludePadTlv(self):
		"""This signifies the selection of the check box to include Pad TLV.

		Returns:
			bool
		"""
		return self._get_attribute('enableIncludePadTlv')
	@EnableIncludePadTlv.setter
	def EnableIncludePadTlv(self, value):
		self._set_attribute('enableIncludePadTlv', value)

	@property
	def EnableIncludeVendorEnterpriseNumberTlv(self):
		"""This signifies the selection of the checkbox to include the the TLV number of the vendor organization.

		Returns:
			bool
		"""
		return self._get_attribute('enableIncludeVendorEnterpriseNumberTlv')
	@EnableIncludeVendorEnterpriseNumberTlv.setter
	def EnableIncludeVendorEnterpriseNumberTlv(self, value):
		self._set_attribute('enableIncludeVendorEnterpriseNumberTlv', value)

	@property
	def EnablePauseResumeBfdPduTrigger(self):
		"""This signifies the pausing of the BFD PDU trigger.

		Returns:
			bool
		"""
		return self._get_attribute('enablePauseResumeBfdPduTrigger')
	@EnablePauseResumeBfdPduTrigger.setter
	def EnablePauseResumeBfdPduTrigger(self, value):
		self._set_attribute('enablePauseResumeBfdPduTrigger', value)

	@property
	def EnablePauseResumeReplyTrigger(self):
		"""This signifies the pausing of the reply trigger.

		Returns:
			bool
		"""
		return self._get_attribute('enablePauseResumeReplyTrigger')
	@EnablePauseResumeReplyTrigger.setter
	def EnablePauseResumeReplyTrigger(self, value):
		self._set_attribute('enablePauseResumeReplyTrigger', value)

	@property
	def EnableSendTriggeredPing(self):
		"""This signifies the sending of the triggered ping.

		Returns:
			bool
		"""
		return self._get_attribute('enableSendTriggeredPing')
	@EnableSendTriggeredPing.setter
	def EnableSendTriggeredPing(self, value):
		self._set_attribute('enableSendTriggeredPing', value)

	@property
	def EnableSendTriggeredTraceroute(self):
		"""This signifies the enablement of the sending of triggered trace route.

		Returns:
			bool
		"""
		return self._get_attribute('enableSendTriggeredTraceroute')
	@EnableSendTriggeredTraceroute.setter
	def EnableSendTriggeredTraceroute(self, value):
		self._set_attribute('enableSendTriggeredTraceroute', value)

	@property
	def EnableSetResetEchoReplyCodeTrigger(self):
		"""This signifies the setting of the echo reply code trigger.

		Returns:
			bool
		"""
		return self._get_attribute('enableSetResetEchoReplyCodeTrigger')
	@EnableSetResetEchoReplyCodeTrigger.setter
	def EnableSetResetEchoReplyCodeTrigger(self, value):
		self._set_attribute('enableSetResetEchoReplyCodeTrigger', value)

	@property
	def IsGeneralLearnedInformationRefreshed(self):
		"""This signifies the refreshing of the general learned information.

		Returns:
			bool
		"""
		return self._get_attribute('isGeneralLearnedInformationRefreshed')

	@property
	def IsTriggeredPingLearnedInformationRefreshed(self):
		"""This signifies the checking of if the Triggered ping learned information is refreshed.

		Returns:
			bool
		"""
		return self._get_attribute('isTriggeredPingLearnedInformationRefreshed')

	@property
	def IsTriggeredTraceRouteLearnedInformationRefreshed(self):
		"""This signifies the checking of if the Triggered Trace route information is refreshed.

		Returns:
			bool
		"""
		return self._get_attribute('isTriggeredTraceRouteLearnedInformationRefreshed')

	@property
	def PadTlvFirstOctetOptions(self):
		"""This signifies the first octate of Pad TLV in triggered ping. Possible values include CopyPadTlvToReply and DropPadTlvFromReply.

		Returns:
			str(dropPadTlvFromReply|copyPadTlvToReply)
		"""
		return self._get_attribute('padTlvFirstOctetOptions')
	@PadTlvFirstOctetOptions.setter
	def PadTlvFirstOctetOptions(self, value):
		self._set_attribute('padTlvFirstOctetOptions', value)

	@property
	def PadTlvLength(self):
		"""This signifies the specification of the length of the Pad TLV.

		Returns:
			number
		"""
		return self._get_attribute('padTlvLength')
	@PadTlvLength.setter
	def PadTlvLength(self, value):
		self._set_attribute('padTlvLength', value)

	@property
	def PauseResumeBfdPduTriggerOption(self):
		"""This signifies the pausing of the BFD PDU trigger option.Possible values include Pause and Resume.

		Returns:
			str(pause|resume)
		"""
		return self._get_attribute('pauseResumeBfdPduTriggerOption')
	@PauseResumeBfdPduTriggerOption.setter
	def PauseResumeBfdPduTriggerOption(self, value):
		self._set_attribute('pauseResumeBfdPduTriggerOption', value)

	@property
	def PauseResumeReplyTriggerOption(self):
		"""This signifies the pausing of the reply trigger option. Possible values include Pause and Resume.

		Returns:
			str(pause|resume)
		"""
		return self._get_attribute('pauseResumeReplyTriggerOption')
	@PauseResumeReplyTriggerOption.setter
	def PauseResumeReplyTriggerOption(self, value):
		self._set_attribute('pauseResumeReplyTriggerOption', value)

	@property
	def ReplyMode(self):
		"""This signifies the selection of the mode of reply. Possible values include:

		Returns:
			str(doNotReply|replyViaIpv4Ipv6UdpPacket|replyViaIpv4Ipv6UdpPacketWithRouterAlert|replyViaApplicationLevelControlChannel)
		"""
		return self._get_attribute('replyMode')
	@ReplyMode.setter
	def ReplyMode(self, value):
		self._set_attribute('replyMode', value)

	@property
	def ReturnCodeOption(self):
		"""This signifies the return code option value. Possible values include:

		Returns:
			str(noReturnCode|malformedEchoRequestReceived|oneOrMoreOfTheTlvsWasNotUnderstood|replyingRouterIsAnEgressForTheFecAtStackDepthRsc|replyingRouterHasNoMappingForTheFecAtStackDepthRsc|downstreamMappingMismatch|upstreamInterfaceIndexUnknown|lspPingReserved|labelSwitchedAtStackDepthRsc|labelSwitchedButNoMplsForwardingAtStackDepthRsc|mappingForThisFecIsNotTheGivenLabelAtStackDepthRsc|noLabelEntryAtStackDepthRsc|protocolNotAssociatedWithInterfaceatFecStackDepthRsc|prematureTerminationOfPingDueToLabelStackShrinkingToSingleLabel)
		"""
		return self._get_attribute('returnCodeOption')
	@ReturnCodeOption.setter
	def ReturnCodeOption(self, value):
		self._set_attribute('returnCodeOption', value)

	@property
	def ReturnSubCode(self):
		"""This signifies the return subcode value.

		Returns:
			number
		"""
		return self._get_attribute('returnSubCode')
	@ReturnSubCode.setter
	def ReturnSubCode(self, value):
		self._set_attribute('returnSubCode', value)

	@property
	def TriggerOptions(self):
		"""This signifies the trigger option value. Possible values include:

		Returns:
			str(tx|rx|txRx)
		"""
		return self._get_attribute('triggerOptions')
	@TriggerOptions.setter
	def TriggerOptions(self, value):
		self._set_attribute('triggerOptions', value)

	@property
	def TriggerType(self):
		"""This signifies the type of the trigger. Possible values include:

		Returns:
			str(resetToNormalReply|forceReplyCode)
		"""
		return self._get_attribute('triggerType')
	@TriggerType.setter
	def TriggerType(self, value):
		self._set_attribute('triggerType', value)

	@property
	def TtlLimit(self):
		"""This signifies the maximum value of TTL up to which the TTL will be incremented while sending echo request packets.

		Returns:
			number
		"""
		return self._get_attribute('ttlLimit')
	@TtlLimit.setter
	def TtlLimit(self, value):
		self._set_attribute('ttlLimit', value)

	@property
	def VendorEnterpriseNumber(self):
		"""This signifies the specification of the enterprise number of the vendor.

		Returns:
			number
		"""
		return self._get_attribute('vendorEnterpriseNumber')
	@VendorEnterpriseNumber.setter
	def VendorEnterpriseNumber(self, value):
		self._set_attribute('vendorEnterpriseNumber', value)

	def update(self, DestinationAddressIpv4=None, DownstreamAddressType=None, DownstreamInterfaceAddress=None, DownstreamIpAddress=None, EchoResponseTimeoutMs=None, EnableAdvance=None, EnableDsiFlag=None, EnableDsnFlag=None, EnableFecValidation=None, EnableIncludeDownstreamMappingTlv=None, EnableIncludePadTlv=None, EnableIncludeVendorEnterpriseNumberTlv=None, EnablePauseResumeBfdPduTrigger=None, EnablePauseResumeReplyTrigger=None, EnableSendTriggeredPing=None, EnableSendTriggeredTraceroute=None, EnableSetResetEchoReplyCodeTrigger=None, PadTlvFirstOctetOptions=None, PadTlvLength=None, PauseResumeBfdPduTriggerOption=None, PauseResumeReplyTriggerOption=None, ReplyMode=None, ReturnCodeOption=None, ReturnSubCode=None, TriggerOptions=None, TriggerType=None, TtlLimit=None, VendorEnterpriseNumber=None):
		"""Updates a child instance of learnedInformation on the server.

		Args:
			DestinationAddressIpv4 (str): This signifies the destination IPv4 address.
			DownstreamAddressType (str(ipv4Numbered|ipv4UnNumbered)): This signifies the address type of the downstream traffic. Possible values include Ipv4Numbered and Ipv4UnNumbered.
			DownstreamInterfaceAddress (str): This signifies the interface address of the downstream LSR.
			DownstreamIpAddress (str): This signifies the IPv4/IPv6 address of the downstream LSR.
			EchoResponseTimeoutMs (number): This signifies the minimum tiomeout interval, in milliseconds, between received Echo packets that this interface is capable of supporting.
			EnableAdvance (bool): This signifies the enablement of advance.
			EnableDsiFlag (bool): This signifies the activation of the DS I Flag.
			EnableDsnFlag (bool): This signifies the activation of the DN S Flag.
			EnableFecValidation (bool): This signifies the selection of the check box to enable FEC validation.
			EnableIncludeDownstreamMappingTlv (bool): This signifies the inclusion of the downstream mapping TLV in triggered Trace Route.
			EnableIncludePadTlv (bool): This signifies the selection of the check box to include Pad TLV.
			EnableIncludeVendorEnterpriseNumberTlv (bool): This signifies the selection of the checkbox to include the the TLV number of the vendor organization.
			EnablePauseResumeBfdPduTrigger (bool): This signifies the pausing of the BFD PDU trigger.
			EnablePauseResumeReplyTrigger (bool): This signifies the pausing of the reply trigger.
			EnableSendTriggeredPing (bool): This signifies the sending of the triggered ping.
			EnableSendTriggeredTraceroute (bool): This signifies the enablement of the sending of triggered trace route.
			EnableSetResetEchoReplyCodeTrigger (bool): This signifies the setting of the echo reply code trigger.
			PadTlvFirstOctetOptions (str(dropPadTlvFromReply|copyPadTlvToReply)): This signifies the first octate of Pad TLV in triggered ping. Possible values include CopyPadTlvToReply and DropPadTlvFromReply.
			PadTlvLength (number): This signifies the specification of the length of the Pad TLV.
			PauseResumeBfdPduTriggerOption (str(pause|resume)): This signifies the pausing of the BFD PDU trigger option.Possible values include Pause and Resume.
			PauseResumeReplyTriggerOption (str(pause|resume)): This signifies the pausing of the reply trigger option. Possible values include Pause and Resume.
			ReplyMode (str(doNotReply|replyViaIpv4Ipv6UdpPacket|replyViaIpv4Ipv6UdpPacketWithRouterAlert|replyViaApplicationLevelControlChannel)): This signifies the selection of the mode of reply. Possible values include:
			ReturnCodeOption (str(noReturnCode|malformedEchoRequestReceived|oneOrMoreOfTheTlvsWasNotUnderstood|replyingRouterIsAnEgressForTheFecAtStackDepthRsc|replyingRouterHasNoMappingForTheFecAtStackDepthRsc|downstreamMappingMismatch|upstreamInterfaceIndexUnknown|lspPingReserved|labelSwitchedAtStackDepthRsc|labelSwitchedButNoMplsForwardingAtStackDepthRsc|mappingForThisFecIsNotTheGivenLabelAtStackDepthRsc|noLabelEntryAtStackDepthRsc|protocolNotAssociatedWithInterfaceatFecStackDepthRsc|prematureTerminationOfPingDueToLabelStackShrinkingToSingleLabel)): This signifies the return code option value. Possible values include:
			ReturnSubCode (number): This signifies the return subcode value.
			TriggerOptions (str(tx|rx|txRx)): This signifies the trigger option value. Possible values include:
			TriggerType (str(resetToNormalReply|forceReplyCode)): This signifies the type of the trigger. Possible values include:
			TtlLimit (number): This signifies the maximum value of TTL up to which the TTL will be incremented while sending echo request packets.
			VendorEnterpriseNumber (number): This signifies the specification of the enterprise number of the vendor.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def find(self, DestinationAddressIpv4=None, DownstreamAddressType=None, DownstreamInterfaceAddress=None, DownstreamIpAddress=None, EchoResponseTimeoutMs=None, EnableAdvance=None, EnableDsiFlag=None, EnableDsnFlag=None, EnableFecValidation=None, EnableIncludeDownstreamMappingTlv=None, EnableIncludePadTlv=None, EnableIncludeVendorEnterpriseNumberTlv=None, EnablePauseResumeBfdPduTrigger=None, EnablePauseResumeReplyTrigger=None, EnableSendTriggeredPing=None, EnableSendTriggeredTraceroute=None, EnableSetResetEchoReplyCodeTrigger=None, IsGeneralLearnedInformationRefreshed=None, IsTriggeredPingLearnedInformationRefreshed=None, IsTriggeredTraceRouteLearnedInformationRefreshed=None, PadTlvFirstOctetOptions=None, PadTlvLength=None, PauseResumeBfdPduTriggerOption=None, PauseResumeReplyTriggerOption=None, ReplyMode=None, ReturnCodeOption=None, ReturnSubCode=None, TriggerOptions=None, TriggerType=None, TtlLimit=None, VendorEnterpriseNumber=None):
		"""Finds and retrieves learnedInformation data from the server.

		All named parameters support regex and can be used to selectively retrieve learnedInformation data from the server.
		By default the find method takes no parameters and will retrieve all learnedInformation data from the server.

		Args:
			DestinationAddressIpv4 (str): This signifies the destination IPv4 address.
			DownstreamAddressType (str(ipv4Numbered|ipv4UnNumbered)): This signifies the address type of the downstream traffic. Possible values include Ipv4Numbered and Ipv4UnNumbered.
			DownstreamInterfaceAddress (str): This signifies the interface address of the downstream LSR.
			DownstreamIpAddress (str): This signifies the IPv4/IPv6 address of the downstream LSR.
			EchoResponseTimeoutMs (number): This signifies the minimum tiomeout interval, in milliseconds, between received Echo packets that this interface is capable of supporting.
			EnableAdvance (bool): This signifies the enablement of advance.
			EnableDsiFlag (bool): This signifies the activation of the DS I Flag.
			EnableDsnFlag (bool): This signifies the activation of the DN S Flag.
			EnableFecValidation (bool): This signifies the selection of the check box to enable FEC validation.
			EnableIncludeDownstreamMappingTlv (bool): This signifies the inclusion of the downstream mapping TLV in triggered Trace Route.
			EnableIncludePadTlv (bool): This signifies the selection of the check box to include Pad TLV.
			EnableIncludeVendorEnterpriseNumberTlv (bool): This signifies the selection of the checkbox to include the the TLV number of the vendor organization.
			EnablePauseResumeBfdPduTrigger (bool): This signifies the pausing of the BFD PDU trigger.
			EnablePauseResumeReplyTrigger (bool): This signifies the pausing of the reply trigger.
			EnableSendTriggeredPing (bool): This signifies the sending of the triggered ping.
			EnableSendTriggeredTraceroute (bool): This signifies the enablement of the sending of triggered trace route.
			EnableSetResetEchoReplyCodeTrigger (bool): This signifies the setting of the echo reply code trigger.
			IsGeneralLearnedInformationRefreshed (bool): This signifies the refreshing of the general learned information.
			IsTriggeredPingLearnedInformationRefreshed (bool): This signifies the checking of if the Triggered ping learned information is refreshed.
			IsTriggeredTraceRouteLearnedInformationRefreshed (bool): This signifies the checking of if the Triggered Trace route information is refreshed.
			PadTlvFirstOctetOptions (str(dropPadTlvFromReply|copyPadTlvToReply)): This signifies the first octate of Pad TLV in triggered ping. Possible values include CopyPadTlvToReply and DropPadTlvFromReply.
			PadTlvLength (number): This signifies the specification of the length of the Pad TLV.
			PauseResumeBfdPduTriggerOption (str(pause|resume)): This signifies the pausing of the BFD PDU trigger option.Possible values include Pause and Resume.
			PauseResumeReplyTriggerOption (str(pause|resume)): This signifies the pausing of the reply trigger option. Possible values include Pause and Resume.
			ReplyMode (str(doNotReply|replyViaIpv4Ipv6UdpPacket|replyViaIpv4Ipv6UdpPacketWithRouterAlert|replyViaApplicationLevelControlChannel)): This signifies the selection of the mode of reply. Possible values include:
			ReturnCodeOption (str(noReturnCode|malformedEchoRequestReceived|oneOrMoreOfTheTlvsWasNotUnderstood|replyingRouterIsAnEgressForTheFecAtStackDepthRsc|replyingRouterHasNoMappingForTheFecAtStackDepthRsc|downstreamMappingMismatch|upstreamInterfaceIndexUnknown|lspPingReserved|labelSwitchedAtStackDepthRsc|labelSwitchedButNoMplsForwardingAtStackDepthRsc|mappingForThisFecIsNotTheGivenLabelAtStackDepthRsc|noLabelEntryAtStackDepthRsc|protocolNotAssociatedWithInterfaceatFecStackDepthRsc|prematureTerminationOfPingDueToLabelStackShrinkingToSingleLabel)): This signifies the return code option value. Possible values include:
			ReturnSubCode (number): This signifies the return subcode value.
			TriggerOptions (str(tx|rx|txRx)): This signifies the trigger option value. Possible values include:
			TriggerType (str(resetToNormalReply|forceReplyCode)): This signifies the type of the trigger. Possible values include:
			TtlLimit (number): This signifies the maximum value of TTL up to which the TTL will be incremented while sending echo request packets.
			VendorEnterpriseNumber (number): This signifies the specification of the enterprise number of the vendor.

		Returns:
			self: This instance with matching learnedInformation data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of learnedInformation data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the learnedInformation data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def ClearRecordsForTrigger(self):
		"""Executes the clearRecordsForTrigger operation on the server.

		This signifies the record cleared for trigger settings.

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('clearRecordsForTrigger', payload=payload, response_object=None)

	def RefreshLearnedInformation(self):
		"""Executes the refreshLearnedInformation operation on the server.

		This signifies that the learned information is refreshed.

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('refreshLearnedInformation', payload=payload, response_object=None)

	def Trigger(self):
		"""Executes the trigger operation on the server.

		This signifies the learned info trigger settings.

			Returns:
				number: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('trigger', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class HighLevelStream(Base):
	"""The HighLevelStream class encapsulates a system managed highLevelStream node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the HighLevelStream property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'highLevelStream'

	def __init__(self, parent):
		super(HighLevelStream, self).__init__(parent)

	@property
	def FramePayload(self):
		"""An instance of the FramePayload class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.highlevelstream.framepayload.framepayload.FramePayload)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.highlevelstream.framepayload.framepayload import FramePayload
		return FramePayload(self)._select()

	@property
	def FrameRate(self):
		"""An instance of the FrameRate class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.highlevelstream.framerate.framerate.FrameRate)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.highlevelstream.framerate.framerate import FrameRate
		return FrameRate(self)._select()

	@property
	def FrameSize(self):
		"""An instance of the FrameSize class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.highlevelstream.framesize.framesize.FrameSize)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.highlevelstream.framesize.framesize import FrameSize
		return FrameSize(self)._select()

	@property
	def Stack(self):
		"""An instance of the Stack class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.highlevelstream.stack.stack.Stack)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.highlevelstream.stack.stack import Stack
		return Stack(self)

	@property
	def StackLink(self):
		"""An instance of the StackLink class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.highlevelstream.stacklink.stacklink.StackLink)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.highlevelstream.stacklink.stacklink import StackLink
		return StackLink(self)

	@property
	def TableUdf(self):
		"""An instance of the TableUdf class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.highlevelstream.tableudf.tableudf.TableUdf)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.highlevelstream.tableudf.tableudf import TableUdf
		return TableUdf(self)

	@property
	def TransmissionControl(self):
		"""An instance of the TransmissionControl class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.highlevelstream.transmissioncontrol.transmissioncontrol.TransmissionControl)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.highlevelstream.transmissioncontrol.transmissioncontrol import TransmissionControl
		return TransmissionControl(self)._select()

	@property
	def Udf(self):
		"""An instance of the Udf class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.highlevelstream.udf.udf.Udf)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.highlevelstream.udf.udf import Udf
		return Udf(self)

	@property
	def AppliedFrameSize(self):
		"""(Read only) Indicates the applied frame size of the high level stream.

		Returns:
			str
		"""
		return self._get_attribute('appliedFrameSize')

	@property
	def AppliedPacketCount(self):
		"""(Read only) Indicates the aplied packet count of the high level stream.

		Returns:
			number
		"""
		return self._get_attribute('appliedPacketCount')

	@property
	def Crc(self):
		"""The Cyclic Redundancy Check frame of the configured high level stream.

		Returns:
			str(badCrc|goodCrc)
		"""
		return self._get_attribute('crc')
	@Crc.setter
	def Crc(self, value):
		self._set_attribute('crc', value)

	@property
	def CurrentPacketCount(self):
		"""(Read only) Denotes the number of packets.

		Returns:
			number
		"""
		return self._get_attribute('currentPacketCount')

	@property
	def DestinationMacMode(self):
		"""The mode in which the Destination MAC Address is configured, either manual or ARP.

		Returns:
			str(arp|manual)
		"""
		return self._get_attribute('destinationMacMode')
	@DestinationMacMode.setter
	def DestinationMacMode(self, value):
		self._set_attribute('destinationMacMode', value)

	@property
	def Distributions(self):
		"""Denotes the distribution of the high level stream.

		Returns:
			list(dict(arg1:str,arg2:str))
		"""
		return self._get_attribute('distributions')

	@property
	def Enabled(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def EncapsulationName(self):
		"""Name of the configured encapsulation type.

		Returns:
			str
		"""
		return self._get_attribute('encapsulationName')

	@property
	def EndpointSetId(self):
		"""The ID of the configured endpoint set.

		Returns:
			number
		"""
		return self._get_attribute('endpointSetId')

	@property
	def Name(self):
		"""An alphanumeric string that returns the name of the field.

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def OverSubscribed(self):
		"""If true, the rate is oversubscribed.

		Returns:
			bool
		"""
		return self._get_attribute('overSubscribed')

	@property
	def Pause(self):
		"""If true then pause is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('pause')
	@Pause.setter
	def Pause(self, value):
		self._set_attribute('pause', value)

	@property
	def PreambleCustomSize(self):
		"""Customizes the preamble size of the frame.

		Returns:
			number
		"""
		return self._get_attribute('preambleCustomSize')
	@PreambleCustomSize.setter
	def PreambleCustomSize(self, value):
		self._set_attribute('preambleCustomSize', value)

	@property
	def PreambleFrameSizeMode(self):
		"""The starting size of the frame.

		Returns:
			str(auto|custom)
		"""
		return self._get_attribute('preambleFrameSizeMode')
	@PreambleFrameSizeMode.setter
	def PreambleFrameSizeMode(self, value):
		self._set_attribute('preambleFrameSizeMode', value)

	@property
	def RxPortIds(self):
		"""A list of virtual ports that are the receiving ports

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/lag|/api/v1/sessions/1/ixnetwork/vport])
		"""
		return self._get_attribute('rxPortIds')
	@RxPortIds.setter
	def RxPortIds(self, value):
		self._set_attribute('rxPortIds', value)

	@property
	def RxPortNames(self):
		"""A list of names from the receiving virtual ports.

		Returns:
			list(str)
		"""
		return self._get_attribute('rxPortNames')

	@property
	def State(self):
		"""(Read only) Denotes the current state of the stream.

		Returns:
			str
		"""
		return self._get_attribute('state')

	@property
	def Suspend(self):
		"""Suspends all traffic on this high level stream.

		Returns:
			bool
		"""
		return self._get_attribute('suspend')
	@Suspend.setter
	def Suspend(self, value):
		self._set_attribute('suspend', value)

	@property
	def TxPortId(self):
		"""The virtual port that is the transmitting port.

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/lag|/api/v1/sessions/1/ixnetwork/vport)
		"""
		return self._get_attribute('txPortId')
	@TxPortId.setter
	def TxPortId(self, value):
		self._set_attribute('txPortId', value)

	@property
	def TxPortName(self):
		"""The name of the virtual port that is the transmitting port.

		Returns:
			str
		"""
		return self._get_attribute('txPortName')

	def update(self, Crc=None, DestinationMacMode=None, Enabled=None, Name=None, Pause=None, PreambleCustomSize=None, PreambleFrameSizeMode=None, RxPortIds=None, Suspend=None, TxPortId=None):
		"""Updates a child instance of highLevelStream on the server.

		Args:
			Crc (str(badCrc|goodCrc)): The Cyclic Redundancy Check frame of the configured high level stream.
			DestinationMacMode (str(arp|manual)): The mode in which the Destination MAC Address is configured, either manual or ARP.
			Enabled (bool): 
			Name (str): An alphanumeric string that returns the name of the field.
			Pause (bool): If true then pause is enabled.
			PreambleCustomSize (number): Customizes the preamble size of the frame.
			PreambleFrameSizeMode (str(auto|custom)): The starting size of the frame.
			RxPortIds (list(str[None|/api/v1/sessions/1/ixnetwork/lag|/api/v1/sessions/1/ixnetwork/vport])): A list of virtual ports that are the receiving ports
			Suspend (bool): Suspends all traffic on this high level stream.
			TxPortId (str(None|/api/v1/sessions/1/ixnetwork/lag|/api/v1/sessions/1/ixnetwork/vport)): The virtual port that is the transmitting port.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def find(self, AppliedFrameSize=None, AppliedPacketCount=None, Crc=None, CurrentPacketCount=None, DestinationMacMode=None, Distributions=None, Enabled=None, EncapsulationName=None, EndpointSetId=None, Name=None, OverSubscribed=None, Pause=None, PreambleCustomSize=None, PreambleFrameSizeMode=None, RxPortIds=None, RxPortNames=None, State=None, Suspend=None, TxPortId=None, TxPortName=None):
		"""Finds and retrieves highLevelStream data from the server.

		All named parameters support regex and can be used to selectively retrieve highLevelStream data from the server.
		By default the find method takes no parameters and will retrieve all highLevelStream data from the server.

		Args:
			AppliedFrameSize (str): (Read only) Indicates the applied frame size of the high level stream.
			AppliedPacketCount (number): (Read only) Indicates the aplied packet count of the high level stream.
			Crc (str(badCrc|goodCrc)): The Cyclic Redundancy Check frame of the configured high level stream.
			CurrentPacketCount (number): (Read only) Denotes the number of packets.
			DestinationMacMode (str(arp|manual)): The mode in which the Destination MAC Address is configured, either manual or ARP.
			Distributions (list(dict(arg1:str,arg2:str))): Denotes the distribution of the high level stream.
			Enabled (bool): 
			EncapsulationName (str): Name of the configured encapsulation type.
			EndpointSetId (number): The ID of the configured endpoint set.
			Name (str): An alphanumeric string that returns the name of the field.
			OverSubscribed (bool): If true, the rate is oversubscribed.
			Pause (bool): If true then pause is enabled.
			PreambleCustomSize (number): Customizes the preamble size of the frame.
			PreambleFrameSizeMode (str(auto|custom)): The starting size of the frame.
			RxPortIds (list(str[None|/api/v1/sessions/1/ixnetwork/lag|/api/v1/sessions/1/ixnetwork/vport])): A list of virtual ports that are the receiving ports
			RxPortNames (list(str)): A list of names from the receiving virtual ports.
			State (str): (Read only) Denotes the current state of the stream.
			Suspend (bool): Suspends all traffic on this high level stream.
			TxPortId (str(None|/api/v1/sessions/1/ixnetwork/lag|/api/v1/sessions/1/ixnetwork/vport)): The virtual port that is the transmitting port.
			TxPortName (str): The name of the virtual port that is the transmitting port.

		Returns:
			self: This instance with matching highLevelStream data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of highLevelStream data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the highLevelStream data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def DeleteQuickFlowGroups(self):
		"""Executes the deleteQuickFlowGroups operation on the server.

		Deletes a list of quick flow groups.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		return self._execute('deleteQuickFlowGroups', payload=payload, response_object=None)

	def PreviewFlowPackets(self, *args, **kwargs):
		"""Executes the previewFlowPackets operation on the server.

		Preview packets for selected highLevelstream

		previewFlowPackets(Arg2:number, Arg3:number)object
			Args:
				args[0] is Arg2 (number): 
				args[1] is Arg3 (number): 

			Returns:
				dict(arg1:number,arg2:number,arg3:list[str],arg4:list[list[str]]): No return value.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('previewFlowPackets', payload=payload, response_object=None)

	def StartStatelessTraffic(self):
		"""Executes the startStatelessTraffic operation on the server.

		Start the traffic configuration for stateless traffic items only.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		return self._execute('startStatelessTraffic', payload=payload, response_object=None)

	def StartStatelessTrafficBlocking(self):
		"""Executes the startStatelessTrafficBlocking operation on the server.

		Start the traffic configuration for stateless traffic items only. This will block until traffic is fully started.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		return self._execute('startStatelessTrafficBlocking', payload=payload, response_object=None)

	def StopStatelessTraffic(self):
		"""Executes the stopStatelessTraffic operation on the server.

		Stop the stateless traffic items.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		return self._execute('stopStatelessTraffic', payload=payload, response_object=None)

	def StopStatelessTrafficBlocking(self):
		"""Executes the stopStatelessTrafficBlocking operation on the server.

		Stop the traffic configuration for stateless traffic items only. This will block until traffic is fully stopped.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		return self._execute('stopStatelessTrafficBlocking', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Ospfv2Router(Base):
	"""The Ospfv2Router class encapsulates a system managed ospfv2Router node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Ospfv2Router property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'ospfv2Router'

	def __init__(self, parent):
		super(Ospfv2Router, self).__init__(parent)

	@property
	def OspfBierSubDomainList(self):
		"""An instance of the OspfBierSubDomainList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ospfbiersubdomainlist.OspfBierSubDomainList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ospfbiersubdomainlist import OspfBierSubDomainList
		return OspfBierSubDomainList(self)._select()

	@property
	def OspfSRAlgorithmList(self):
		"""An instance of the OspfSRAlgorithmList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ospfsralgorithmlist.OspfSRAlgorithmList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ospfsralgorithmlist import OspfSRAlgorithmList
		return OspfSRAlgorithmList(self)

	@property
	def OspfSRGBRangeSubObjectsList(self):
		"""An instance of the OspfSRGBRangeSubObjectsList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ospfsrgbrangesubobjectslist.OspfSRGBRangeSubObjectsList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ospfsrgbrangesubobjectslist import OspfSRGBRangeSubObjectsList
		return OspfSRGBRangeSubObjectsList(self)

	@property
	def BIERPrefix(self):
		"""A BFR's BFR-Prefix is an IP address (either IPv4 or IPv6) of the BFR, and MUST be unique and routable within the BIER domain.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('BIERPrefix')

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def Algorithm(self):
		"""Algorithm for the Node SID/Label

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('algorithm')

	@property
	def BBit(self):
		"""Router-LSA B-Bit

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bBit')

	@property
	def BierAFlag(self):
		"""Attach Flag: If set an Area Border Router (ABR) will generate an Extended Prefix TLV for inter-area prefix that is locally connected or attached in other connected area

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bierAFlag')

	@property
	def BierNFlag(self):
		"""Node Flag: Set when the prefix identifies the advertising router i.e., the prefix is a host prefix advertising a globally reachable address typically associated with a loopback address

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bierNFlag')

	@property
	def ConfigureSIDIndexLabel(self):
		"""Configure SID/Index/Label

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('configureSIDIndexLabel')

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def DiscardLearnedLsa(self):
		"""Discard Learned LSAs

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('discardLearnedLsa')

	@property
	def DoNotGenerateRouterLsa(self):
		"""Generate Router LSA.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('doNotGenerateRouterLsa')

	@property
	def EBit(self):
		"""Router-LSA E-Bit

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('eBit')

	@property
	def EFlag(self):
		"""Explicit-Null Flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('eFlag')

	@property
	def EnableBIER(self):
		"""Enable BIER

		Returns:
			bool
		"""
		return self._get_attribute('enableBIER')
	@EnableBIER.setter
	def EnableBIER(self, value):
		self._set_attribute('enableBIER', value)

	@property
	def EnableMappingServer(self):
		"""Enable Mapping Server of Segment Routing

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableMappingServer')

	@property
	def EnableSegmentRouting(self):
		"""Enable Segment Routing

		Returns:
			bool
		"""
		return self._get_attribute('enableSegmentRouting')
	@EnableSegmentRouting.setter
	def EnableSegmentRouting(self, value):
		self._set_attribute('enableSegmentRouting', value)

	@property
	def Errors(self):
		"""A list of errors that have occurred

		Returns:
			list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))
		"""
		return self._get_attribute('errors')

	@property
	def GracefulRestart(self):
		"""Enable Graceful Restart,if enabled Discard Learned LSAs should be disabled in order to learn the LSAs

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('gracefulRestart')

	@property
	def InterFloodLsUpdateBurstGap(self):
		"""Inter Flood LSUpdate burst gap (ms)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('interFloodLsUpdateBurstGap')

	@property
	def LFlag(self):
		"""Local or Global Flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lFlag')

	@property
	def LocalRouterID(self):
		"""Router ID

		Returns:
			list(str)
		"""
		return self._get_attribute('localRouterID')

	@property
	def LoopBackAddress(self):
		"""Router ID

		Returns:
			list(str)
		"""
		return self._get_attribute('loopBackAddress')

	@property
	def LsaRefreshTime(self):
		"""LSA Refresh time (s)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lsaRefreshTime')

	@property
	def LsaRetransmitTime(self):
		"""LSA Retransmit time(s)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lsaRetransmitTime')

	@property
	def MFlag(self):
		"""Mapping Server Flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('mFlag')

	@property
	def MaxLsUpdatesPerBurst(self):
		"""Max Flood LSUpdates Per Burst

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('maxLsUpdatesPerBurst')

	@property
	def Name(self):
		"""Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def NoOfAddressPrefix(self):
		"""Number Of Address Prefix Range

		Returns:
			number
		"""
		return self._get_attribute('noOfAddressPrefix')
	@NoOfAddressPrefix.setter
	def NoOfAddressPrefix(self, value):
		self._set_attribute('noOfAddressPrefix', value)

	@property
	def NoOfBIERSubDomains(self):
		"""Number of BIER Sub Domains

		Returns:
			number
		"""
		return self._get_attribute('noOfBIERSubDomains')
	@NoOfBIERSubDomains.setter
	def NoOfBIERSubDomains(self, value):
		self._set_attribute('noOfBIERSubDomains', value)

	@property
	def NpFlag(self):
		"""No-PHP Flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('npFlag')

	@property
	def OobResyncBreakout(self):
		"""Enable out-of-band resynchronization breakout

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('oobResyncBreakout')

	@property
	def SRAlgorithmCount(self):
		"""SR Algorithm Count

		Returns:
			number
		"""
		return self._get_attribute('sRAlgorithmCount')
	@SRAlgorithmCount.setter
	def SRAlgorithmCount(self, value):
		self._set_attribute('sRAlgorithmCount', value)

	@property
	def SessionInfo(self):
		"""Logs additional information about the session Information

		Returns:
			list(str[noIfaceUp|sameNbrRouterId|up])
		"""
		return self._get_attribute('sessionInfo')

	@property
	def SessionStatus(self):
		"""Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.

		Returns:
			list(str[down|notStarted|up])
		"""
		return self._get_attribute('sessionStatus')

	@property
	def SidIndexLabel(self):
		"""SID/Index/Label

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sidIndexLabel')

	@property
	def SrgbRangeCount(self):
		"""SRGB Range Count

		Returns:
			number
		"""
		return self._get_attribute('srgbRangeCount')
	@SrgbRangeCount.setter
	def SrgbRangeCount(self, value):
		self._set_attribute('srgbRangeCount', value)

	@property
	def StateCounts(self):
		"""A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up

		Returns:
			dict(total:number,notStarted:number,down:number,up:number)
		"""
		return self._get_attribute('stateCounts')

	@property
	def Status(self):
		"""Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			str(configured|error|mixed|notStarted|started|starting|stopping)
		"""
		return self._get_attribute('status')

	@property
	def StrictLsaChecking(self):
		"""Terminate graceful restart when an LSA has changed

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('strictLsaChecking')

	@property
	def SupportForRfc3623(self):
		"""Support RFC 3623 features,if enabled Discard Learned LSAs should be disabled in order to learn the LSAs

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('supportForRfc3623')

	@property
	def SupportReasonSoftReloadUpgrade(self):
		"""Support graceful restart helper mode when restart reason is Software Reload or Upgrade.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('supportReasonSoftReloadUpgrade')

	@property
	def SupportReasonSoftRestart(self):
		"""Support graceful restart helper mode when restart reason is OSPFv2 software restart.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('supportReasonSoftRestart')

	@property
	def SupportReasonSwitchRedundantCntrlProcessor(self):
		"""Support graceful restart helper mode when restart reason is unplanned switchover.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('supportReasonSwitchRedundantCntrlProcessor')

	@property
	def SupportReasonUnknown(self):
		"""Support graceful restart helper mode when restart reason is unknown and unplanned.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('supportReasonUnknown')

	@property
	def VFlag(self):
		"""Value or Index Flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('vFlag')

	def update(self, EnableBIER=None, EnableSegmentRouting=None, Name=None, NoOfAddressPrefix=None, NoOfBIERSubDomains=None, SRAlgorithmCount=None, SrgbRangeCount=None):
		"""Updates a child instance of ospfv2Router on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			EnableBIER (bool): Enable BIER
			EnableSegmentRouting (bool): Enable Segment Routing
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NoOfAddressPrefix (number): Number Of Address Prefix Range
			NoOfBIERSubDomains (number): Number of BIER Sub Domains
			SRAlgorithmCount (number): SR Algorithm Count
			SrgbRangeCount (number): SRGB Range Count

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def find(self, Count=None, DescriptiveName=None, EnableBIER=None, EnableSegmentRouting=None, Errors=None, LocalRouterID=None, LoopBackAddress=None, Name=None, NoOfAddressPrefix=None, NoOfBIERSubDomains=None, SRAlgorithmCount=None, SessionInfo=None, SessionStatus=None, SrgbRangeCount=None, StateCounts=None, Status=None):
		"""Finds and retrieves ospfv2Router data from the server.

		All named parameters support regex and can be used to selectively retrieve ospfv2Router data from the server.
		By default the find method takes no parameters and will retrieve all ospfv2Router data from the server.

		Args:
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			EnableBIER (bool): Enable BIER
			EnableSegmentRouting (bool): Enable Segment Routing
			Errors (list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))): A list of errors that have occurred
			LocalRouterID (list(str)): Router ID
			LoopBackAddress (list(str)): Router ID
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NoOfAddressPrefix (number): Number Of Address Prefix Range
			NoOfBIERSubDomains (number): Number of BIER Sub Domains
			SRAlgorithmCount (number): SR Algorithm Count
			SessionInfo (list(str[noIfaceUp|sameNbrRouterId|up])): Logs additional information about the session Information
			SessionStatus (list(str[down|notStarted|up])): Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.
			SrgbRangeCount (number): SRGB Range Count
			StateCounts (dict(total:number,notStarted:number,down:number,up:number)): A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up
			Status (str(configured|error|mixed|notStarted|started|starting|stopping)): Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			self: This instance with matching ospfv2Router data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of ospfv2Router data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the ospfv2Router data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, BIERPrefix=None, Active=None, Algorithm=None, BBit=None, BierAFlag=None, BierNFlag=None, ConfigureSIDIndexLabel=None, DiscardLearnedLsa=None, DoNotGenerateRouterLsa=None, EBit=None, EFlag=None, EnableMappingServer=None, GracefulRestart=None, InterFloodLsUpdateBurstGap=None, LFlag=None, LsaRefreshTime=None, LsaRetransmitTime=None, MFlag=None, MaxLsUpdatesPerBurst=None, NpFlag=None, OobResyncBreakout=None, SidIndexLabel=None, StrictLsaChecking=None, SupportForRfc3623=None, SupportReasonSoftReloadUpgrade=None, SupportReasonSoftRestart=None, SupportReasonSwitchRedundantCntrlProcessor=None, SupportReasonUnknown=None, VFlag=None):
		"""Base class infrastructure that gets a list of ospfv2Router device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			BIERPrefix (str): optional regex of BIERPrefix
			Active (str): optional regex of active
			Algorithm (str): optional regex of algorithm
			BBit (str): optional regex of bBit
			BierAFlag (str): optional regex of bierAFlag
			BierNFlag (str): optional regex of bierNFlag
			ConfigureSIDIndexLabel (str): optional regex of configureSIDIndexLabel
			DiscardLearnedLsa (str): optional regex of discardLearnedLsa
			DoNotGenerateRouterLsa (str): optional regex of doNotGenerateRouterLsa
			EBit (str): optional regex of eBit
			EFlag (str): optional regex of eFlag
			EnableMappingServer (str): optional regex of enableMappingServer
			GracefulRestart (str): optional regex of gracefulRestart
			InterFloodLsUpdateBurstGap (str): optional regex of interFloodLsUpdateBurstGap
			LFlag (str): optional regex of lFlag
			LsaRefreshTime (str): optional regex of lsaRefreshTime
			LsaRetransmitTime (str): optional regex of lsaRetransmitTime
			MFlag (str): optional regex of mFlag
			MaxLsUpdatesPerBurst (str): optional regex of maxLsUpdatesPerBurst
			NpFlag (str): optional regex of npFlag
			OobResyncBreakout (str): optional regex of oobResyncBreakout
			SidIndexLabel (str): optional regex of sidIndexLabel
			StrictLsaChecking (str): optional regex of strictLsaChecking
			SupportForRfc3623 (str): optional regex of supportForRfc3623
			SupportReasonSoftReloadUpgrade (str): optional regex of supportReasonSoftReloadUpgrade
			SupportReasonSoftRestart (str): optional regex of supportReasonSoftRestart
			SupportReasonSwitchRedundantCntrlProcessor (str): optional regex of supportReasonSwitchRedundantCntrlProcessor
			SupportReasonUnknown (str): optional regex of supportReasonUnknown
			VFlag (str): optional regex of vFlag

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def OspfStartRouter(self, *args, **kwargs):
		"""Executes the ospfStartRouter operation on the server.

		Start OSPF Router

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		ospfStartRouter()

		ospfStartRouter(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		ospfStartRouter(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('ospfStartRouter', payload=payload, response_object=None)

	def OspfStopRouter(self, *args, **kwargs):
		"""Executes the ospfStopRouter operation on the server.

		Stop OSPF Router

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		ospfStopRouter()

		ospfStopRouter(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		ospfStopRouter(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('ospfStopRouter', payload=payload, response_object=None)

	def RestartDown(self, *args, **kwargs):
		"""Executes the restartDown operation on the server.

		Stop and start interfaces and sessions that are in Down state.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		restartDown()

		restartDown(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		restartDown(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('restartDown', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Start selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		start(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self, *args, **kwargs):
		"""Executes the stop operation on the server.

		Stop selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stop()

		stop(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stop(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stop', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class OpenFlow(Base):
	"""The OpenFlow class encapsulates a required openFlow node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the OpenFlow property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'openFlow'

	def __init__(self, parent):
		super(OpenFlow, self).__init__(parent)

	@property
	def Device(self):
		"""An instance of the Device class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.device.Device)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.device import Device
		return Device(self)

	@property
	def EthernetTrafficEndPoint(self):
		"""An instance of the EthernetTrafficEndPoint class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.ethernettrafficendpoint.EthernetTrafficEndPoint)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.ethernettrafficendpoint import EthernetTrafficEndPoint
		return EthernetTrafficEndPoint(self)

	@property
	def HostTopologyLearnedInformation(self):
		"""An instance of the HostTopologyLearnedInformation class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.hosttopologylearnedinformation.HostTopologyLearnedInformation)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.hosttopologylearnedinformation import HostTopologyLearnedInformation
		return HostTopologyLearnedInformation(self)._select()

	@property
	def Ipv4TrafficEndPoint(self):
		"""An instance of the Ipv4TrafficEndPoint class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.ipv4trafficendpoint.Ipv4TrafficEndPoint)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.ipv4trafficendpoint import Ipv4TrafficEndPoint
		return Ipv4TrafficEndPoint(self)

	@property
	def Ipv6TrafficEndPoint(self):
		"""An instance of the Ipv6TrafficEndPoint class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.ipv6trafficendpoint.Ipv6TrafficEndPoint)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.ipv6trafficendpoint import Ipv6TrafficEndPoint
		return Ipv6TrafficEndPoint(self)

	@property
	def LearnedInformation(self):
		"""An instance of the LearnedInformation class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.learnedinformation.LearnedInformation)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.learnedinformation import LearnedInformation
		return LearnedInformation(self)._select()

	@property
	def MplsTrafficEndPoint(self):
		"""An instance of the MplsTrafficEndPoint class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.mplstrafficendpoint.MplsTrafficEndPoint)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.mplstrafficendpoint import MplsTrafficEndPoint
		return MplsTrafficEndPoint(self)

	@property
	def OfTopologyLearnedInformation(self):
		"""An instance of the OfTopologyLearnedInformation class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.oftopologylearnedinformation.OfTopologyLearnedInformation)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.oftopologylearnedinformation import OfTopologyLearnedInformation
		return OfTopologyLearnedInformation(self)._select()

	@property
	def SwitchLearnedInformation(self):
		"""An instance of the SwitchLearnedInformation class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchlearnedinformation.SwitchLearnedInformation)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchlearnedinformation import SwitchLearnedInformation
		return SwitchLearnedInformation(self)._select()

	@property
	def TrafficEndPoint(self):
		"""An instance of the TrafficEndPoint class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.trafficendpoint.TrafficEndPoint)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.trafficendpoint import TrafficEndPoint
		return TrafficEndPoint(self)

	@property
	def Enabled(self):
		"""If true, the openFlow object is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def PortRole(self):
		"""Indicates the role of the port in the protocol configuration.

		Returns:
			str(control|traffic|controlAndTraffic)
		"""
		return self._get_attribute('portRole')
	@PortRole.setter
	def PortRole(self, value):
		self._set_attribute('portRole', value)

	@property
	def RunningState(self):
		"""Indicates the state of the OpenFlow protocol on the port.

		Returns:
			str(unknown|stopped|stopping|starting|started)
		"""
		return self._get_attribute('runningState')

	def update(self, Enabled=None, PortRole=None):
		"""Updates a child instance of openFlow on the server.

		Args:
			Enabled (bool): If true, the openFlow object is enabled.
			PortRole (str(control|traffic|controlAndTraffic)): Indicates the role of the port in the protocol configuration.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def Start(self):
		"""Executes the start operation on the server.

		This describes the start value of the trigger settings.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self):
		"""Executes the stop operation on the server.

		This describes the stop value of the trigger settings.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('stop', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class SwitchGroupFeature(Base):
	"""The SwitchGroupFeature class encapsulates a system managed switchGroupFeature node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the SwitchGroupFeature property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'switchGroupFeature'

	def __init__(self, parent):
		super(SwitchGroupFeature, self).__init__(parent)

	@property
	def ApplyGroup(self):
		"""If selected, table supports Apply Group capability.

		Returns:
			bool
		"""
		return self._get_attribute('applyGroup')
	@ApplyGroup.setter
	def ApplyGroup(self, value):
		self._set_attribute('applyGroup', value)

	@property
	def CopyTtlIn(self):
		"""If selected, table supports Copy TTL In capability.

		Returns:
			bool
		"""
		return self._get_attribute('copyTtlIn')
	@CopyTtlIn.setter
	def CopyTtlIn(self, value):
		self._set_attribute('copyTtlIn', value)

	@property
	def CopyTtlOut(self):
		"""If selected, table supports Copy TTL capability.

		Returns:
			bool
		"""
		return self._get_attribute('copyTtlOut')
	@CopyTtlOut.setter
	def CopyTtlOut(self, value):
		self._set_attribute('copyTtlOut', value)

	@property
	def DecrementMplsTtl(self):
		"""If selected, table supports Decrement MPLS TTL capability.

		Returns:
			bool
		"""
		return self._get_attribute('decrementMplsTtl')
	@DecrementMplsTtl.setter
	def DecrementMplsTtl(self, value):
		self._set_attribute('decrementMplsTtl', value)

	@property
	def DecrementNetworkTtl(self):
		"""If selected, table supports Decrement Network TTL capability.

		Returns:
			bool
		"""
		return self._get_attribute('decrementNetworkTtl')
	@DecrementNetworkTtl.setter
	def DecrementNetworkTtl(self, value):
		self._set_attribute('decrementNetworkTtl', value)

	@property
	def GroupType(self):
		"""The type of group. (This type is selected in the Switches window.)

		Returns:
			str(allGroup|selectGroup|indirectGroup|fastFailoverGroup)
		"""
		return self._get_attribute('groupType')

	@property
	def MaxNoOfGroups(self):
		"""Specify the maximum number of groups supported per switch group type.

		Returns:
			number
		"""
		return self._get_attribute('maxNoOfGroups')
	@MaxNoOfGroups.setter
	def MaxNoOfGroups(self, value):
		self._set_attribute('maxNoOfGroups', value)

	@property
	def Output(self):
		"""If selected, table supports Output capability.

		Returns:
			bool
		"""
		return self._get_attribute('output')
	@Output.setter
	def Output(self, value):
		self._set_attribute('output', value)

	@property
	def PopMpls(self):
		"""If selected, table supports Pop MPLS capability.

		Returns:
			bool
		"""
		return self._get_attribute('popMpls')
	@PopMpls.setter
	def PopMpls(self, value):
		self._set_attribute('popMpls', value)

	@property
	def PopPbb(self):
		"""If selected, table supports Experimenter capability.

		Returns:
			bool
		"""
		return self._get_attribute('popPbb')
	@PopPbb.setter
	def PopPbb(self, value):
		self._set_attribute('popPbb', value)

	@property
	def PopVlan(self):
		"""If selected, table supports Pop VLAN capability.

		Returns:
			bool
		"""
		return self._get_attribute('popVlan')
	@PopVlan.setter
	def PopVlan(self, value):
		self._set_attribute('popVlan', value)

	@property
	def PushMpls(self):
		"""If selected, table supports Push MPLS capability.

		Returns:
			bool
		"""
		return self._get_attribute('pushMpls')
	@PushMpls.setter
	def PushMpls(self, value):
		self._set_attribute('pushMpls', value)

	@property
	def PushPbb(self):
		"""If selected, table supports Push PBB capability.

		Returns:
			bool
		"""
		return self._get_attribute('pushPbb')
	@PushPbb.setter
	def PushPbb(self, value):
		self._set_attribute('pushPbb', value)

	@property
	def PushVlan(self):
		"""If selected, table supports Push VLAN capability.

		Returns:
			bool
		"""
		return self._get_attribute('pushVlan')
	@PushVlan.setter
	def PushVlan(self, value):
		self._set_attribute('pushVlan', value)

	@property
	def SetField(self):
		"""If selected, table supports Set Field capability.

		Returns:
			bool
		"""
		return self._get_attribute('setField')
	@SetField.setter
	def SetField(self, value):
		self._set_attribute('setField', value)

	@property
	def SetMplsTtl(self):
		"""If selected, table supports Set MPLS TTL capability.

		Returns:
			bool
		"""
		return self._get_attribute('setMplsTtl')
	@SetMplsTtl.setter
	def SetMplsTtl(self, value):
		self._set_attribute('setMplsTtl', value)

	@property
	def SetNetworkTtl(self):
		"""If selected, table supports Set Network TTL capability.

		Returns:
			bool
		"""
		return self._get_attribute('setNetworkTtl')
	@SetNetworkTtl.setter
	def SetNetworkTtl(self, value):
		self._set_attribute('setNetworkTtl', value)

	@property
	def SetQueue(self):
		"""If selected, table supports Set Queue capability.

		Returns:
			bool
		"""
		return self._get_attribute('setQueue')
	@SetQueue.setter
	def SetQueue(self, value):
		self._set_attribute('setQueue', value)

	def update(self, ApplyGroup=None, CopyTtlIn=None, CopyTtlOut=None, DecrementMplsTtl=None, DecrementNetworkTtl=None, MaxNoOfGroups=None, Output=None, PopMpls=None, PopPbb=None, PopVlan=None, PushMpls=None, PushPbb=None, PushVlan=None, SetField=None, SetMplsTtl=None, SetNetworkTtl=None, SetQueue=None):
		"""Updates a child instance of switchGroupFeature on the server.

		Args:
			ApplyGroup (bool): If selected, table supports Apply Group capability.
			CopyTtlIn (bool): If selected, table supports Copy TTL In capability.
			CopyTtlOut (bool): If selected, table supports Copy TTL capability.
			DecrementMplsTtl (bool): If selected, table supports Decrement MPLS TTL capability.
			DecrementNetworkTtl (bool): If selected, table supports Decrement Network TTL capability.
			MaxNoOfGroups (number): Specify the maximum number of groups supported per switch group type.
			Output (bool): If selected, table supports Output capability.
			PopMpls (bool): If selected, table supports Pop MPLS capability.
			PopPbb (bool): If selected, table supports Experimenter capability.
			PopVlan (bool): If selected, table supports Pop VLAN capability.
			PushMpls (bool): If selected, table supports Push MPLS capability.
			PushPbb (bool): If selected, table supports Push PBB capability.
			PushVlan (bool): If selected, table supports Push VLAN capability.
			SetField (bool): If selected, table supports Set Field capability.
			SetMplsTtl (bool): If selected, table supports Set MPLS TTL capability.
			SetNetworkTtl (bool): If selected, table supports Set Network TTL capability.
			SetQueue (bool): If selected, table supports Set Queue capability.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def find(self, ApplyGroup=None, CopyTtlIn=None, CopyTtlOut=None, DecrementMplsTtl=None, DecrementNetworkTtl=None, GroupType=None, MaxNoOfGroups=None, Output=None, PopMpls=None, PopPbb=None, PopVlan=None, PushMpls=None, PushPbb=None, PushVlan=None, SetField=None, SetMplsTtl=None, SetNetworkTtl=None, SetQueue=None):
		"""Finds and retrieves switchGroupFeature data from the server.

		All named parameters support regex and can be used to selectively retrieve switchGroupFeature data from the server.
		By default the find method takes no parameters and will retrieve all switchGroupFeature data from the server.

		Args:
			ApplyGroup (bool): If selected, table supports Apply Group capability.
			CopyTtlIn (bool): If selected, table supports Copy TTL In capability.
			CopyTtlOut (bool): If selected, table supports Copy TTL capability.
			DecrementMplsTtl (bool): If selected, table supports Decrement MPLS TTL capability.
			DecrementNetworkTtl (bool): If selected, table supports Decrement Network TTL capability.
			GroupType (str(allGroup|selectGroup|indirectGroup|fastFailoverGroup)): The type of group. (This type is selected in the Switches window.)
			MaxNoOfGroups (number): Specify the maximum number of groups supported per switch group type.
			Output (bool): If selected, table supports Output capability.
			PopMpls (bool): If selected, table supports Pop MPLS capability.
			PopPbb (bool): If selected, table supports Experimenter capability.
			PopVlan (bool): If selected, table supports Pop VLAN capability.
			PushMpls (bool): If selected, table supports Push MPLS capability.
			PushPbb (bool): If selected, table supports Push PBB capability.
			PushVlan (bool): If selected, table supports Push VLAN capability.
			SetField (bool): If selected, table supports Set Field capability.
			SetMplsTtl (bool): If selected, table supports Set MPLS TTL capability.
			SetNetworkTtl (bool): If selected, table supports Set Network TTL capability.
			SetQueue (bool): If selected, table supports Set Queue capability.

		Returns:
			self: This instance with matching switchGroupFeature data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of switchGroupFeature data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the switchGroupFeature data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



"""Demonstrates different types of patterns that can be set in
	TestPlatform.Sessions.IxNetwork.Topology...Multivalue objects

"""
from ixnetwork_restpy.testplatform.testplatform import TestPlatform


# connect to a test tool platform
test_platform = TestPlatform('127.0.0.1')

# use the default session and get the root node of the hierarhcy
ixnetwork = test_platform.Sessions.find().Ixnetwork

# clear any configuration that may be present
ixnetwork.NewConfig()

# add virtual ports
vports = ixnetwork.Vport.add().add().add().add()
vports.info(vports)

# add ipv4 devices
ipv4 = ixnetwork.Topology.add(Ports=vports).DeviceGroup.add(Multiplier=10).Ethernet.add().Ipv4.add()

# set single multivalue
ipv4.Address.Single('6.6.6.6')
ipv4.info(ipv4.Address)
assert(ipv4.Address.Pattern == '6.6.6.6')

# add overlays
ipv4.Address.Overlay(3, '1.2.3.4')
ipv4.Address.Overlay(6, '4.3.2.1')

# set increment multivalue
ipv4.Address.Increment(start_value='7.7.7.7', step_value='8.8.8.8')
ipv4.info(ipv4.Address)
assert(ipv4.Address.Pattern.startswith('Inc:') is True)

# set decrement multivalue
ipv4.Address.Decrement(start_value='6.6.6.6', step_value='5.5.5.5')
ipv4.info(ipv4.Address)
assert(ipv4.Address.Pattern.startswith('Dec:') is True)

# set custom multivalue
ipv4.Address.Custom(start_value='6.6.6.6', step_value='5.5.5.5', increments=[('3.3.3.3', 12, [('2.2.2.2', 20, [])])])
ipv4.info(ipv4.Address)
assert(ipv4.Address.Pattern.startswith('Custom:') is True)

# set valuelist multivalue
ipv4.Address.ValueList(['10.10.10.10', '11.11.11.11'])
ipv4.info(ipv4.Address)
assert(ipv4.Address.Pattern.startswith('List:') is True)

# set random multivalue
ipv4.Address.Random()
ipv4.info(ipv4.Address)
assert(ipv4.Address.Pattern.startswith('Rand') is True)

# set repeatable random range multivalue
ipv4.Address.RandomRange(min_value='1.1.1.1', max_value='2.2.2.2', step_value='0.0.0.1', seed=7)
ipv4.info(ipv4.Address)
assert(ipv4.Address.Pattern.startswith('Randr:') is True)

# set repeatable random multivalue
ipv4.Address.RandomMask(fixed_value='1.1.1.1', mask_value='0.0.0.1', seed=7, count=6)
ipv4.info(ipv4.Address)
assert(ipv4.Address.Pattern.startswith('Randb:') is True)
